unit RedeemerEntities;

interface

uses
  StrUtils, SysUtils;

type
  TEntityName = record
    Name: Ansistring;
    Code: Cardinal;
  end;

function UCS4Chr(c: Cardinal): UnicodeString;
function RemoveEntities(s: string): string;

const
  Entities: array[0..2124] of TEntityName = (
                                            (Name: 'AElig'; Code: $000000C6),
                                            (Name: 'AMP'; Code: $00000026),
                                            (Name: 'Aacute'; Code: $000000C1),
                                            (Name: 'Abreve;'; Code: $00000102),
                                            (Name: 'Acirc'; Code: $000000C2),
                                            (Name: 'Acy;'; Code: $00000410),
                                            (Name: 'Afr;'; Code: $DD04D835),
                                            (Name: 'Agrave'; Code: $000000C0),
                                            (Name: 'Alpha;'; Code: $00000391),
                                            (Name: 'Amacr;'; Code: $00000100),
                                            (Name: 'And;'; Code: $00002A53),
                                            (Name: 'Aogon;'; Code: $00000104),
                                            (Name: 'Aopf;'; Code: $DD38D835),
                                            (Name: 'ApplyFunction;'; Code: $00002061),
                                            (Name: 'Aring'; Code: $000000C5),
                                            (Name: 'Ascr;'; Code: $DC9CD835),
                                            (Name: 'Assign;'; Code: $00002254),
                                            (Name: 'Atilde'; Code: $000000C3),
                                            (Name: 'Auml'; Code: $000000C4),
                                            (Name: 'Backslash;'; Code: $00002216),
                                            (Name: 'Barv;'; Code: $00002AE7),
                                            (Name: 'Barwed;'; Code: $00002306),
                                            (Name: 'Bcy;'; Code: $00000411),
                                            (Name: 'Because;'; Code: $00002235),
                                            (Name: 'Bernoullis;'; Code: $0000212C),
                                            (Name: 'Beta;'; Code: $00000392),
                                            (Name: 'Bfr;'; Code: $DD05D835),
                                            (Name: 'Bopf;'; Code: $DD39D835),
                                            (Name: 'Breve;'; Code: $000002D8),
                                            (Name: 'Bscr;'; Code: $0000212C),
                                            (Name: 'Bumpeq;'; Code: $0000224E),
                                            (Name: 'CHcy;'; Code: $00000427),
                                            (Name: 'COPY'; Code: $000000A9),
                                            (Name: 'Cacute;'; Code: $00000106),
                                            (Name: 'Cap;'; Code: $000022D2),
                                            (Name: 'CapitalDifferentialD;'; Code: $00002145),
                                            (Name: 'Cayleys;'; Code: $0000212D),
                                            (Name: 'Ccaron;'; Code: $0000010C),
                                            (Name: 'Ccedil'; Code: $000000C7),
                                            (Name: 'Ccirc;'; Code: $00000108),
                                            (Name: 'Cconint;'; Code: $00002230),
                                            (Name: 'Cdot;'; Code: $0000010A),
                                            (Name: 'Cedilla;'; Code: $000000B8),
                                            (Name: 'CenterDot;'; Code: $000000B7),
                                            (Name: 'Cfr;'; Code: $0000212D),
                                            (Name: 'Chi;'; Code: $000003A7),
                                            (Name: 'CircleDot;'; Code: $00002299),
                                            (Name: 'CircleMinus;'; Code: $00002296),
                                            (Name: 'CirclePlus;'; Code: $00002295),
                                            (Name: 'CircleTimes;'; Code: $00002297),
                                            (Name: 'ClockwiseContourIntegral;'; Code: $00002232),
                                            (Name: 'CloseCurlyDoubleQuote;'; Code: $0000201D),
                                            (Name: 'CloseCurlyQuote;'; Code: $00002019),
                                            (Name: 'Colon;'; Code: $00002237),
                                            (Name: 'Colone;'; Code: $00002A74),
                                            (Name: 'Congruent;'; Code: $00002261),
                                            (Name: 'Conint;'; Code: $0000222F),
                                            (Name: 'ContourIntegral;'; Code: $0000222E),
                                            (Name: 'Copf;'; Code: $00002102),
                                            (Name: 'Coproduct;'; Code: $00002210),
                                            (Name: 'CounterClockwiseContourIntegral;'; Code: $00002233),
                                            (Name: 'Cross;'; Code: $00002A2F),
                                            (Name: 'Cscr;'; Code: $DC9ED835),
                                            (Name: 'Cup;'; Code: $000022D3),
                                            (Name: 'CupCap;'; Code: $0000224D),
                                            (Name: 'DD;'; Code: $00002145),
                                            (Name: 'DDotrahd;'; Code: $00002911),
                                            (Name: 'DJcy;'; Code: $00000402),
                                            (Name: 'DScy;'; Code: $00000405),
                                            (Name: 'DZcy;'; Code: $0000040F),
                                            (Name: 'Dagger;'; Code: $00002021),
                                            (Name: 'Darr;'; Code: $000021A1),
                                            (Name: 'Dashv;'; Code: $00002AE4),
                                            (Name: 'Dcaron;'; Code: $0000010E),
                                            (Name: 'Dcy;'; Code: $00000414),
                                            (Name: 'Del;'; Code: $00002207),
                                            (Name: 'Delta;'; Code: $00000394),
                                            (Name: 'Dfr;'; Code: $DD07D835),
                                            (Name: 'DiacriticalAcute;'; Code: $000000B4),
                                            (Name: 'DiacriticalDot;'; Code: $000002D9),
                                            (Name: 'DiacriticalDoubleAcute;'; Code: $000002DD),
                                            (Name: 'DiacriticalGrave;'; Code: $00000060),
                                            (Name: 'DiacriticalTilde;'; Code: $000002DC),
                                            (Name: 'Diamond;'; Code: $000022C4),
                                            (Name: 'DifferentialD;'; Code: $00002146),
                                            (Name: 'Dopf;'; Code: $DD3BD835),
                                            (Name: 'Dot;'; Code: $000000A8),
                                            (Name: 'DotDot;'; Code: $000020DC),
                                            (Name: 'DotEqual;'; Code: $00002250),
                                            (Name: 'DoubleContourIntegral;'; Code: $0000222F),
                                            (Name: 'DoubleDot;'; Code: $000000A8),
                                            (Name: 'DoubleDownArrow;'; Code: $000021D3),
                                            (Name: 'DoubleLeftArrow;'; Code: $000021D0),
                                            (Name: 'DoubleLeftRightArrow;'; Code: $000021D4),
                                            (Name: 'DoubleLeftTee;'; Code: $00002AE4),
                                            (Name: 'DoubleLongLeftArrow;'; Code: $000027F8),
                                            (Name: 'DoubleLongLeftRightArrow;'; Code: $000027FA),
                                            (Name: 'DoubleLongRightArrow;'; Code: $000027F9),
                                            (Name: 'DoubleRightArrow;'; Code: $000021D2),
                                            (Name: 'DoubleRightTee;'; Code: $000022A8),
                                            (Name: 'DoubleUpArrow;'; Code: $000021D1),
                                            (Name: 'DoubleUpDownArrow;'; Code: $000021D5),
                                            (Name: 'DoubleVerticalBar;'; Code: $00002225),
                                            (Name: 'DownArrow;'; Code: $00002193),
                                            (Name: 'DownArrowBar;'; Code: $00002913),
                                            (Name: 'DownArrowUpArrow;'; Code: $000021F5),
                                            (Name: 'DownBreve;'; Code: $00000311),
                                            (Name: 'DownLeftRightVector;'; Code: $00002950),
                                            (Name: 'DownLeftTeeVector;'; Code: $0000295E),
                                            (Name: 'DownLeftVector;'; Code: $000021BD),
                                            (Name: 'DownLeftVectorBar;'; Code: $00002956),
                                            (Name: 'DownRightTeeVector;'; Code: $0000295F),
                                            (Name: 'DownRightVector;'; Code: $000021C1),
                                            (Name: 'DownRightVectorBar;'; Code: $00002957),
                                            (Name: 'DownTee;'; Code: $000022A4),
                                            (Name: 'DownTeeArrow;'; Code: $000021A7),
                                            (Name: 'Downarrow;'; Code: $000021D3),
                                            (Name: 'Dscr;'; Code: $DC9FD835),
                                            (Name: 'Dstrok;'; Code: $00000110),
                                            (Name: 'ENG;'; Code: $0000014A),
                                            (Name: 'ETH'; Code: $000000D0),
                                            (Name: 'Eacute'; Code: $000000C9),
                                            (Name: 'Ecaron;'; Code: $0000011A),
                                            (Name: 'Ecirc'; Code: $000000CA),
                                            (Name: 'Ecy;'; Code: $0000042D),
                                            (Name: 'Edot;'; Code: $00000116),
                                            (Name: 'Efr;'; Code: $DD08D835),
                                            (Name: 'Egrave'; Code: $000000C8),
                                            (Name: 'Element;'; Code: $00002208),
                                            (Name: 'Emacr;'; Code: $00000112),
                                            (Name: 'EmptySmallSquare;'; Code: $000025FB),
                                            (Name: 'EmptyVerySmallSquare;'; Code: $000025AB),
                                            (Name: 'Eogon;'; Code: $00000118),
                                            (Name: 'Eopf;'; Code: $DD3CD835),
                                            (Name: 'Epsilon;'; Code: $00000395),
                                            (Name: 'Equal;'; Code: $00002A75),
                                            (Name: 'EqualTilde;'; Code: $00002242),
                                            (Name: 'Equilibrium;'; Code: $000021CC),
                                            (Name: 'Escr;'; Code: $00002130),
                                            (Name: 'Esim;'; Code: $00002A73),
                                            (Name: 'Eta;'; Code: $00000397),
                                            (Name: 'Euml'; Code: $000000CB),
                                            (Name: 'Exists;'; Code: $00002203),
                                            (Name: 'ExponentialE;'; Code: $00002147),
                                            (Name: 'Fcy;'; Code: $00000424),
                                            (Name: 'Ffr;'; Code: $DD09D835),
                                            (Name: 'FilledSmallSquare;'; Code: $000025FC),
                                            (Name: 'FilledVerySmallSquare;'; Code: $000025AA),
                                            (Name: 'Fopf;'; Code: $DD3DD835),
                                            (Name: 'ForAll;'; Code: $00002200),
                                            (Name: 'Fouriertrf;'; Code: $00002131),
                                            (Name: 'Fscr;'; Code: $00002131),
                                            (Name: 'GJcy;'; Code: $00000403),
                                            (Name: 'GT'; Code: $0000003E),
                                            (Name: 'Gamma;'; Code: $00000393),
                                            (Name: 'Gammad;'; Code: $000003DC),
                                            (Name: 'Gbreve;'; Code: $0000011E),
                                            (Name: 'Gcedil;'; Code: $00000122),
                                            (Name: 'Gcirc;'; Code: $0000011C),
                                            (Name: 'Gcy;'; Code: $00000413),
                                            (Name: 'Gdot;'; Code: $00000120),
                                            (Name: 'Gfr;'; Code: $DD0AD835),
                                            (Name: 'Gg;'; Code: $000022D9),
                                            (Name: 'Gopf;'; Code: $DD3ED835),
                                            (Name: 'GreaterEqual;'; Code: $00002265),
                                            (Name: 'GreaterEqualLess;'; Code: $000022DB),
                                            (Name: 'GreaterFullEqual;'; Code: $00002267),
                                            (Name: 'GreaterGreater;'; Code: $00002AA2),
                                            (Name: 'GreaterLess;'; Code: $00002277),
                                            (Name: 'GreaterSlantEqual;'; Code: $00002A7E),
                                            (Name: 'GreaterTilde;'; Code: $00002273),
                                            (Name: 'Gscr;'; Code: $DCA2D835),
                                            (Name: 'Gt;'; Code: $0000226B),
                                            (Name: 'HARDcy;'; Code: $0000042A),
                                            (Name: 'Hacek;'; Code: $000002C7),
                                            (Name: 'Hat;'; Code: $0000005E),
                                            (Name: 'Hcirc;'; Code: $00000124),
                                            (Name: 'Hfr;'; Code: $0000210C),
                                            (Name: 'HilbertSpace;'; Code: $0000210B),
                                            (Name: 'Hopf;'; Code: $0000210D),
                                            (Name: 'HorizontalLine;'; Code: $00002500),
                                            (Name: 'Hscr;'; Code: $0000210B),
                                            (Name: 'Hstrok;'; Code: $00000126),
                                            (Name: 'HumpDownHump;'; Code: $0000224E),
                                            (Name: 'HumpEqual;'; Code: $0000224F),
                                            (Name: 'IEcy;'; Code: $00000415),
                                            (Name: 'IJlig;'; Code: $00000132),
                                            (Name: 'IOcy;'; Code: $00000401),
                                            (Name: 'Iacute'; Code: $000000CD),
                                            (Name: 'Icirc'; Code: $000000CE),
                                            (Name: 'Icy;'; Code: $00000418),
                                            (Name: 'Idot;'; Code: $00000130),
                                            (Name: 'Ifr;'; Code: $00002111),
                                            (Name: 'Igrave'; Code: $000000CC),
                                            (Name: 'Im;'; Code: $00002111),
                                            (Name: 'Imacr;'; Code: $0000012A),
                                            (Name: 'ImaginaryI;'; Code: $00002148),
                                            (Name: 'Implies;'; Code: $000021D2),
                                            (Name: 'Int;'; Code: $0000222C),
                                            (Name: 'Integral;'; Code: $0000222B),
                                            (Name: 'Intersection;'; Code: $000022C2),
                                            (Name: 'InvisibleComma;'; Code: $00002063),
                                            (Name: 'InvisibleTimes;'; Code: $00002062),
                                            (Name: 'Iogon;'; Code: $0000012E),
                                            (Name: 'Iopf;'; Code: $DD40D835),
                                            (Name: 'Iota;'; Code: $00000399),
                                            (Name: 'Iscr;'; Code: $00002110),
                                            (Name: 'Itilde;'; Code: $00000128),
                                            (Name: 'Iukcy;'; Code: $00000406),
                                            (Name: 'Iuml'; Code: $000000CF),
                                            (Name: 'Jcirc;'; Code: $00000134),
                                            (Name: 'Jcy;'; Code: $00000419),
                                            (Name: 'Jfr;'; Code: $DD0DD835),
                                            (Name: 'Jopf;'; Code: $DD41D835),
                                            (Name: 'Jscr;'; Code: $DCA5D835),
                                            (Name: 'Jsercy;'; Code: $00000408),
                                            (Name: 'Jukcy;'; Code: $00000404),
                                            (Name: 'KHcy;'; Code: $00000425),
                                            (Name: 'KJcy;'; Code: $0000040C),
                                            (Name: 'Kappa;'; Code: $0000039A),
                                            (Name: 'Kcedil;'; Code: $00000136),
                                            (Name: 'Kcy;'; Code: $0000041A),
                                            (Name: 'Kfr;'; Code: $DD0ED835),
                                            (Name: 'Kopf;'; Code: $DD42D835),
                                            (Name: 'Kscr;'; Code: $DCA6D835),
                                            (Name: 'LJcy;'; Code: $00000409),
                                            (Name: 'LT'; Code: $0000003C),
                                            (Name: 'Lacute;'; Code: $00000139),
                                            (Name: 'Lambda;'; Code: $0000039B),
                                            (Name: 'Lang;'; Code: $000027EA),
                                            (Name: 'Laplacetrf;'; Code: $00002112),
                                            (Name: 'Larr;'; Code: $0000219E),
                                            (Name: 'Lcaron;'; Code: $0000013D),
                                            (Name: 'Lcedil;'; Code: $0000013B),
                                            (Name: 'Lcy;'; Code: $0000041B),
                                            (Name: 'LeftAngleBracket;'; Code: $000027E8),
                                            (Name: 'LeftArrow;'; Code: $00002190),
                                            (Name: 'LeftArrowBar;'; Code: $000021E4),
                                            (Name: 'LeftArrowRightArrow;'; Code: $000021C6),
                                            (Name: 'LeftCeiling;'; Code: $00002308),
                                            (Name: 'LeftDoubleBracket;'; Code: $000027E6),
                                            (Name: 'LeftDownTeeVector;'; Code: $00002961),
                                            (Name: 'LeftDownVector;'; Code: $000021C3),
                                            (Name: 'LeftDownVectorBar;'; Code: $00002959),
                                            (Name: 'LeftFloor;'; Code: $0000230A),
                                            (Name: 'LeftRightArrow;'; Code: $00002194),
                                            (Name: 'LeftRightVector;'; Code: $0000294E),
                                            (Name: 'LeftTee;'; Code: $000022A3),
                                            (Name: 'LeftTeeArrow;'; Code: $000021A4),
                                            (Name: 'LeftTeeVector;'; Code: $0000295A),
                                            (Name: 'LeftTriangle;'; Code: $000022B2),
                                            (Name: 'LeftTriangleBar;'; Code: $000029CF),
                                            (Name: 'LeftTriangleEqual;'; Code: $000022B4),
                                            (Name: 'LeftUpDownVector;'; Code: $00002951),
                                            (Name: 'LeftUpTeeVector;'; Code: $00002960),
                                            (Name: 'LeftUpVector;'; Code: $000021BF),
                                            (Name: 'LeftUpVectorBar;'; Code: $00002958),
                                            (Name: 'LeftVector;'; Code: $000021BC),
                                            (Name: 'LeftVectorBar;'; Code: $00002952),
                                            (Name: 'Leftarrow;'; Code: $000021D0),
                                            (Name: 'Leftrightarrow;'; Code: $000021D4),
                                            (Name: 'LessEqualGreater;'; Code: $000022DA),
                                            (Name: 'LessFullEqual;'; Code: $00002266),
                                            (Name: 'LessGreater;'; Code: $00002276),
                                            (Name: 'LessLess;'; Code: $00002AA1),
                                            (Name: 'LessSlantEqual;'; Code: $00002A7D),
                                            (Name: 'LessTilde;'; Code: $00002272),
                                            (Name: 'Lfr;'; Code: $DD0FD835),
                                            (Name: 'Ll;'; Code: $000022D8),
                                            (Name: 'Lleftarrow;'; Code: $000021DA),
                                            (Name: 'Lmidot;'; Code: $0000013F),
                                            (Name: 'LongLeftArrow;'; Code: $000027F5),
                                            (Name: 'LongLeftRightArrow;'; Code: $000027F7),
                                            (Name: 'LongRightArrow;'; Code: $000027F6),
                                            (Name: 'Longleftarrow;'; Code: $000027F8),
                                            (Name: 'Longleftrightarrow;'; Code: $000027FA),
                                            (Name: 'Longrightarrow;'; Code: $000027F9),
                                            (Name: 'Lopf;'; Code: $DD43D835),
                                            (Name: 'LowerLeftArrow;'; Code: $00002199),
                                            (Name: 'LowerRightArrow;'; Code: $00002198),
                                            (Name: 'Lscr;'; Code: $00002112),
                                            (Name: 'Lsh;'; Code: $000021B0),
                                            (Name: 'Lstrok;'; Code: $00000141),
                                            (Name: 'Lt;'; Code: $0000226A),
                                            (Name: 'Map;'; Code: $00002905),
                                            (Name: 'Mcy;'; Code: $0000041C),
                                            (Name: 'MediumSpace;'; Code: $0000205F),
                                            (Name: 'Mellintrf;'; Code: $00002133),
                                            (Name: 'Mfr;'; Code: $DD10D835),
                                            (Name: 'MinusPlus;'; Code: $00002213),
                                            (Name: 'Mopf;'; Code: $DD44D835),
                                            (Name: 'Mscr;'; Code: $00002133),
                                            (Name: 'Mu;'; Code: $0000039C),
                                            (Name: 'NJcy;'; Code: $0000040A),
                                            (Name: 'Nacute;'; Code: $00000143),
                                            (Name: 'Ncaron;'; Code: $00000147),
                                            (Name: 'Ncedil;'; Code: $00000145),
                                            (Name: 'Ncy;'; Code: $0000041D),
                                            (Name: 'NegativeMediumSpace;'; Code: $0000200B),
                                            (Name: 'NegativeThickSpace;'; Code: $0000200B),
                                            (Name: 'NegativeThinSpace;'; Code: $0000200B),
                                            (Name: 'NegativeVeryThinSpace;'; Code: $0000200B),
                                            (Name: 'NestedGreaterGreater;'; Code: $0000226B),
                                            (Name: 'NestedLessLess;'; Code: $0000226A),
                                            (Name: 'NewLine;'; Code: $0000000A),
                                            (Name: 'Nfr;'; Code: $DD11D835),
                                            (Name: 'NoBreak;'; Code: $00002060),
                                            (Name: 'NonBreakingSpace;'; Code: $000000A0),
                                            (Name: 'Nopf;'; Code: $00002115),
                                            (Name: 'Not;'; Code: $00002AEC),
                                            (Name: 'NotCongruent;'; Code: $00002262),
                                            (Name: 'NotCupCap;'; Code: $0000226D),
                                            (Name: 'NotDoubleVerticalBar;'; Code: $00002226),
                                            (Name: 'NotElement;'; Code: $00002209),
                                            (Name: 'NotEqual;'; Code: $00002260),
                                            (Name: 'NotEqualTilde;'; Code: $03382242),
                                            (Name: 'NotExists;'; Code: $00002204),
                                            (Name: 'NotGreater;'; Code: $0000226F),
                                            (Name: 'NotGreaterEqual;'; Code: $00002271),
                                            (Name: 'NotGreaterFullEqual;'; Code: $03382267),
                                            (Name: 'NotGreaterGreater;'; Code: $0338226B),
                                            (Name: 'NotGreaterLess;'; Code: $00002279),
                                            (Name: 'NotGreaterSlantEqual;'; Code: $03382A7E),
                                            (Name: 'NotGreaterTilde;'; Code: $00002275),
                                            (Name: 'NotHumpDownHump;'; Code: $0338224E),
                                            (Name: 'NotHumpEqual;'; Code: $0338224F),
                                            (Name: 'NotLeftTriangle;'; Code: $000022EA),
                                            (Name: 'NotLeftTriangleBar;'; Code: $033829CF),
                                            (Name: 'NotLeftTriangleEqual;'; Code: $000022EC),
                                            (Name: 'NotLess;'; Code: $0000226E),
                                            (Name: 'NotLessEqual;'; Code: $00002270),
                                            (Name: 'NotLessGreater;'; Code: $00002278),
                                            (Name: 'NotLessLess;'; Code: $0338226A),
                                            (Name: 'NotLessSlantEqual;'; Code: $03382A7D),
                                            (Name: 'NotLessTilde;'; Code: $00002274),
                                            (Name: 'NotNestedGreaterGreater;'; Code: $03382AA2),
                                            (Name: 'NotNestedLessLess;'; Code: $03382AA1),
                                            (Name: 'NotPrecedes;'; Code: $00002280),
                                            (Name: 'NotPrecedesEqual;'; Code: $03382AAF),
                                            (Name: 'NotPrecedesSlantEqual;'; Code: $000022E0),
                                            (Name: 'NotReverseElement;'; Code: $0000220C),
                                            (Name: 'NotRightTriangle;'; Code: $000022EB),
                                            (Name: 'NotRightTriangleBar;'; Code: $033829D0),
                                            (Name: 'NotRightTriangleEqual;'; Code: $000022ED),
                                            (Name: 'NotSquareSubset;'; Code: $0338228F),
                                            (Name: 'NotSquareSubsetEqual;'; Code: $000022E2),
                                            (Name: 'NotSquareSuperset;'; Code: $03382290),
                                            (Name: 'NotSquareSupersetEqual;'; Code: $000022E3),
                                            (Name: 'NotSubset;'; Code: $20D22282),
                                            (Name: 'NotSubsetEqual;'; Code: $00002288),
                                            (Name: 'NotSucceeds;'; Code: $00002281),
                                            (Name: 'NotSucceedsEqual;'; Code: $03382AB0),
                                            (Name: 'NotSucceedsSlantEqual;'; Code: $000022E1),
                                            (Name: 'NotSucceedsTilde;'; Code: $0338227F),
                                            (Name: 'NotSuperset;'; Code: $20D22283),
                                            (Name: 'NotSupersetEqual;'; Code: $00002289),
                                            (Name: 'NotTilde;'; Code: $00002241),
                                            (Name: 'NotTildeEqual;'; Code: $00002244),
                                            (Name: 'NotTildeFullEqual;'; Code: $00002247),
                                            (Name: 'NotTildeTilde;'; Code: $00002249),
                                            (Name: 'NotVerticalBar;'; Code: $00002224),
                                            (Name: 'Nscr;'; Code: $DCA9D835),
                                            (Name: 'Ntilde'; Code: $000000D1),
                                            (Name: 'Nu;'; Code: $0000039D),
                                            (Name: 'OElig;'; Code: $00000152),
                                            (Name: 'Oacute'; Code: $000000D3),
                                            (Name: 'Ocirc'; Code: $000000D4),
                                            (Name: 'Ocy;'; Code: $0000041E),
                                            (Name: 'Odblac;'; Code: $00000150),
                                            (Name: 'Ofr;'; Code: $DD12D835),
                                            (Name: 'Ograve'; Code: $000000D2),
                                            (Name: 'Omacr;'; Code: $0000014C),
                                            (Name: 'Omega;'; Code: $000003A9),
                                            (Name: 'Omicron;'; Code: $0000039F),
                                            (Name: 'Oopf;'; Code: $DD46D835),
                                            (Name: 'OpenCurlyDoubleQuote;'; Code: $0000201C),
                                            (Name: 'OpenCurlyQuote;'; Code: $00002018),
                                            (Name: 'Or;'; Code: $00002A54),
                                            (Name: 'Oscr;'; Code: $DCAAD835),
                                            (Name: 'Oslash'; Code: $000000D8),
                                            (Name: 'Otilde'; Code: $000000D5),
                                            (Name: 'Otimes;'; Code: $00002A37),
                                            (Name: 'Ouml'; Code: $000000D6),
                                            (Name: 'OverBar;'; Code: $0000203E),
                                            (Name: 'OverBrace;'; Code: $000023DE),
                                            (Name: 'OverBracket;'; Code: $000023B4),
                                            (Name: 'OverParenthesis;'; Code: $000023DC),
                                            (Name: 'PartialD;'; Code: $00002202),
                                            (Name: 'Pcy;'; Code: $0000041F),
                                            (Name: 'Pfr;'; Code: $DD13D835),
                                            (Name: 'Phi;'; Code: $000003A6),
                                            (Name: 'Pi;'; Code: $000003A0),
                                            (Name: 'PlusMinus;'; Code: $000000B1),
                                            (Name: 'Poincareplane;'; Code: $0000210C),
                                            (Name: 'Popf;'; Code: $00002119),
                                            (Name: 'Pr;'; Code: $00002ABB),
                                            (Name: 'Precedes;'; Code: $0000227A),
                                            (Name: 'PrecedesEqual;'; Code: $00002AAF),
                                            (Name: 'PrecedesSlantEqual;'; Code: $0000227C),
                                            (Name: 'PrecedesTilde;'; Code: $0000227E),
                                            (Name: 'Prime;'; Code: $00002033),
                                            (Name: 'Product;'; Code: $0000220F),
                                            (Name: 'Proportion;'; Code: $00002237),
                                            (Name: 'Proportional;'; Code: $0000221D),
                                            (Name: 'Pscr;'; Code: $DCABD835),
                                            (Name: 'Psi;'; Code: $000003A8),
                                            (Name: 'QUOT;'; Code: $00000022),
                                            (Name: 'Qfr;'; Code: $DD14D835),
                                            (Name: 'Qopf;'; Code: $0000211A),
                                            (Name: 'Qscr;'; Code: $DCACD835),
                                            (Name: 'RBarr;'; Code: $00002910),
                                            (Name: 'REG'; Code: $000000AE),
                                            (Name: 'Racute;'; Code: $00000154),
                                            (Name: 'Rang;'; Code: $000027EB),
                                            (Name: 'Rarr;'; Code: $000021A0),
                                            (Name: 'Rarrtl;'; Code: $00002916),
                                            (Name: 'Rcaron;'; Code: $00000158),
                                            (Name: 'Rcedil;'; Code: $00000156),
                                            (Name: 'Rcy;'; Code: $00000420),
                                            (Name: 'Re;'; Code: $0000211C),
                                            (Name: 'ReverseElement;'; Code: $0000220B),
                                            (Name: 'ReverseEquilibrium;'; Code: $000021CB),
                                            (Name: 'ReverseUpEquilibrium;'; Code: $0000296F),
                                            (Name: 'Rfr;'; Code: $0000211C),
                                            (Name: 'Rho;'; Code: $000003A1),
                                            (Name: 'RightAngleBracket;'; Code: $000027E9),
                                            (Name: 'RightArrow;'; Code: $00002192),
                                            (Name: 'RightArrowBar;'; Code: $000021E5),
                                            (Name: 'RightArrowLeftArrow;'; Code: $000021C4),
                                            (Name: 'RightCeiling;'; Code: $00002309),
                                            (Name: 'RightDoubleBracket;'; Code: $000027E7),
                                            (Name: 'RightDownTeeVector;'; Code: $0000295D),
                                            (Name: 'RightDownVector;'; Code: $000021C2),
                                            (Name: 'RightDownVectorBar;'; Code: $00002955),
                                            (Name: 'RightFloor;'; Code: $0000230B),
                                            (Name: 'RightTee;'; Code: $000022A2),
                                            (Name: 'RightTeeArrow;'; Code: $000021A6),
                                            (Name: 'RightTeeVector;'; Code: $0000295B),
                                            (Name: 'RightTriangle;'; Code: $000022B3),
                                            (Name: 'RightTriangleBar;'; Code: $000029D0),
                                            (Name: 'RightTriangleEqual;'; Code: $000022B5),
                                            (Name: 'RightUpDownVector;'; Code: $0000294F),
                                            (Name: 'RightUpTeeVector;'; Code: $0000295C),
                                            (Name: 'RightUpVector;'; Code: $000021BE),
                                            (Name: 'RightUpVectorBar;'; Code: $00002954),
                                            (Name: 'RightVector;'; Code: $000021C0),
                                            (Name: 'RightVectorBar;'; Code: $00002953),
                                            (Name: 'Rightarrow;'; Code: $000021D2),
                                            (Name: 'Ropf;'; Code: $0000211D),
                                            (Name: 'RoundImplies;'; Code: $00002970),
                                            (Name: 'Rrightarrow;'; Code: $000021DB),
                                            (Name: 'Rscr;'; Code: $0000211B),
                                            (Name: 'Rsh;'; Code: $000021B1),
                                            (Name: 'RuleDelayed;'; Code: $000029F4),
                                            (Name: 'SHCHcy;'; Code: $00000429),
                                            (Name: 'SHcy;'; Code: $00000428),
                                            (Name: 'SOFTcy;'; Code: $0000042C),
                                            (Name: 'Sacute;'; Code: $0000015A),
                                            (Name: 'Sc;'; Code: $00002ABC),
                                            (Name: 'Scaron;'; Code: $00000160),
                                            (Name: 'Scedil;'; Code: $0000015E),
                                            (Name: 'Scirc;'; Code: $0000015C),
                                            (Name: 'Scy;'; Code: $00000421),
                                            (Name: 'Sfr;'; Code: $DD16D835),
                                            (Name: 'ShortDownArrow;'; Code: $00002193),
                                            (Name: 'ShortLeftArrow;'; Code: $00002190),
                                            (Name: 'ShortRightArrow;'; Code: $00002192),
                                            (Name: 'ShortUpArrow;'; Code: $00002191),
                                            (Name: 'Sigma;'; Code: $000003A3),
                                            (Name: 'SmallCircle;'; Code: $00002218),
                                            (Name: 'Sopf;'; Code: $DD4AD835),
                                            (Name: 'Sqrt;'; Code: $0000221A),
                                            (Name: 'Square;'; Code: $000025A1),
                                            (Name: 'SquareIntersection;'; Code: $00002293),
                                            (Name: 'SquareSubset;'; Code: $0000228F),
                                            (Name: 'SquareSubsetEqual;'; Code: $00002291),
                                            (Name: 'SquareSuperset;'; Code: $00002290),
                                            (Name: 'SquareSupersetEqual;'; Code: $00002292),
                                            (Name: 'SquareUnion;'; Code: $00002294),
                                            (Name: 'Sscr;'; Code: $DCAED835),
                                            (Name: 'Star;'; Code: $000022C6),
                                            (Name: 'Sub;'; Code: $000022D0),
                                            (Name: 'Subset;'; Code: $000022D0),
                                            (Name: 'SubsetEqual;'; Code: $00002286),
                                            (Name: 'Succeeds;'; Code: $0000227B),
                                            (Name: 'SucceedsEqual;'; Code: $00002AB0),
                                            (Name: 'SucceedsSlantEqual;'; Code: $0000227D),
                                            (Name: 'SucceedsTilde;'; Code: $0000227F),
                                            (Name: 'SuchThat;'; Code: $0000220B),
                                            (Name: 'Sum;'; Code: $00002211),
                                            (Name: 'Sup;'; Code: $000022D1),
                                            (Name: 'Superset;'; Code: $00002283),
                                            (Name: 'SupersetEqual;'; Code: $00002287),
                                            (Name: 'Supset;'; Code: $000022D1),
                                            (Name: 'THORN'; Code: $000000DE),
                                            (Name: 'TRADE;'; Code: $00002122),
                                            (Name: 'TSHcy;'; Code: $0000040B),
                                            (Name: 'TScy;'; Code: $00000426),
                                            (Name: 'Tab;'; Code: $00000009),
                                            (Name: 'Tau;'; Code: $000003A4),
                                            (Name: 'Tcaron;'; Code: $00000164),
                                            (Name: 'Tcedil;'; Code: $00000162),
                                            (Name: 'Tcy;'; Code: $00000422),
                                            (Name: 'Tfr;'; Code: $DD17D835),
                                            (Name: 'Therefore;'; Code: $00002234),
                                            (Name: 'Theta;'; Code: $00000398),
                                            (Name: 'ThickSpace;'; Code: $200A205F),
                                            (Name: 'ThinSpace;'; Code: $00002009),
                                            (Name: 'Tilde;'; Code: $0000223C),
                                            (Name: 'TildeEqual;'; Code: $00002243),
                                            (Name: 'TildeFullEqual;'; Code: $00002245),
                                            (Name: 'TildeTilde;'; Code: $00002248),
                                            (Name: 'Topf;'; Code: $DD4BD835),
                                            (Name: 'TripleDot;'; Code: $000020DB),
                                            (Name: 'Tscr;'; Code: $DCAFD835),
                                            (Name: 'Tstrok;'; Code: $00000166),
                                            (Name: 'Uacute'; Code: $000000DA),
                                            (Name: 'Uarr;'; Code: $0000219F),
                                            (Name: 'Uarrocir;'; Code: $00002949),
                                            (Name: 'Ubrcy;'; Code: $0000040E),
                                            (Name: 'Ubreve;'; Code: $0000016C),
                                            (Name: 'Ucirc'; Code: $000000DB),
                                            (Name: 'Ucy;'; Code: $00000423),
                                            (Name: 'Udblac;'; Code: $00000170),
                                            (Name: 'Ufr;'; Code: $DD18D835),
                                            (Name: 'Ugrave'; Code: $000000D9),
                                            (Name: 'Umacr;'; Code: $0000016A),
                                            (Name: 'UnderBar;'; Code: $0000005F),
                                            (Name: 'UnderBrace;'; Code: $000023DF),
                                            (Name: 'UnderBracket;'; Code: $000023B5),
                                            (Name: 'UnderParenthesis;'; Code: $000023DD),
                                            (Name: 'Union;'; Code: $000022C3),
                                            (Name: 'UnionPlus;'; Code: $0000228E),
                                            (Name: 'Uogon;'; Code: $00000172),
                                            (Name: 'Uopf;'; Code: $DD4CD835),
                                            (Name: 'UpArrow;'; Code: $00002191),
                                            (Name: 'UpArrowBar;'; Code: $00002912),
                                            (Name: 'UpArrowDownArrow;'; Code: $000021C5),
                                            (Name: 'UpDownArrow;'; Code: $00002195),
                                            (Name: 'UpEquilibrium;'; Code: $0000296E),
                                            (Name: 'UpTee;'; Code: $000022A5),
                                            (Name: 'UpTeeArrow;'; Code: $000021A5),
                                            (Name: 'Uparrow;'; Code: $000021D1),
                                            (Name: 'Updownarrow;'; Code: $000021D5),
                                            (Name: 'UpperLeftArrow;'; Code: $00002196),
                                            (Name: 'UpperRightArrow;'; Code: $00002197),
                                            (Name: 'Upsi;'; Code: $000003D2),
                                            (Name: 'Upsilon;'; Code: $000003A5),
                                            (Name: 'Uring;'; Code: $0000016E),
                                            (Name: 'Uscr;'; Code: $DCB0D835),
                                            (Name: 'Utilde;'; Code: $00000168),
                                            (Name: 'Uuml'; Code: $000000DC),
                                            (Name: 'VDash;'; Code: $000022AB),
                                            (Name: 'Vbar;'; Code: $00002AEB),
                                            (Name: 'Vcy;'; Code: $00000412),
                                            (Name: 'Vdash;'; Code: $000022A9),
                                            (Name: 'Vdashl;'; Code: $00002AE6),
                                            (Name: 'Vee;'; Code: $000022C1),
                                            (Name: 'Verbar;'; Code: $00002016),
                                            (Name: 'Vert;'; Code: $00002016),
                                            (Name: 'VerticalBar;'; Code: $00002223),
                                            (Name: 'VerticalLine;'; Code: $0000007C),
                                            (Name: 'VerticalSeparator;'; Code: $00002758),
                                            (Name: 'VerticalTilde;'; Code: $00002240),
                                            (Name: 'VeryThinSpace;'; Code: $0000200A),
                                            (Name: 'Vfr;'; Code: $DD19D835),
                                            (Name: 'Vopf;'; Code: $DD4DD835),
                                            (Name: 'Vscr;'; Code: $DCB1D835),
                                            (Name: 'Vvdash;'; Code: $000022AA),
                                            (Name: 'Wcirc;'; Code: $00000174),
                                            (Name: 'Wedge;'; Code: $000022C0),
                                            (Name: 'Wfr;'; Code: $DD1AD835),
                                            (Name: 'Wopf;'; Code: $DD4ED835),
                                            (Name: 'Wscr;'; Code: $DCB2D835),
                                            (Name: 'Xfr;'; Code: $DD1BD835),
                                            (Name: 'Xi;'; Code: $0000039E),
                                            (Name: 'Xopf;'; Code: $DD4FD835),
                                            (Name: 'Xscr;'; Code: $DCB3D835),
                                            (Name: 'YAcy;'; Code: $0000042F),
                                            (Name: 'YIcy;'; Code: $00000407),
                                            (Name: 'YUcy;'; Code: $0000042E),
                                            (Name: 'Yacute'; Code: $000000DD),
                                            (Name: 'Ycirc;'; Code: $00000176),
                                            (Name: 'Ycy;'; Code: $0000042B),
                                            (Name: 'Yfr;'; Code: $DD1CD835),
                                            (Name: 'Yopf;'; Code: $DD50D835),
                                            (Name: 'Yscr;'; Code: $DCB4D835),
                                            (Name: 'Yuml;'; Code: $00000178),
                                            (Name: 'ZHcy;'; Code: $00000416),
                                            (Name: 'Zacute;'; Code: $00000179),
                                            (Name: 'Zcaron;'; Code: $0000017D),
                                            (Name: 'Zcy;'; Code: $00000417),
                                            (Name: 'Zdot;'; Code: $0000017B),
                                            (Name: 'ZeroWidthSpace;'; Code: $0000200B),
                                            (Name: 'Zeta;'; Code: $00000396),
                                            (Name: 'Zfr;'; Code: $00002128),
                                            (Name: 'Zopf;'; Code: $00002124),
                                            (Name: 'Zscr;'; Code: $DCB5D835),
                                            (Name: 'aacute'; Code: $000000E1),
                                            (Name: 'abreve;'; Code: $00000103),
                                            (Name: 'ac;'; Code: $0000223E),
                                            (Name: 'acE;'; Code: $0333223E),
                                            (Name: 'acd;'; Code: $0000223F),
                                            (Name: 'acirc'; Code: $000000E2),
                                            (Name: 'acute'; Code: $000000B4),
                                            (Name: 'acy;'; Code: $00000430),
                                            (Name: 'aelig'; Code: $000000E6),
                                            (Name: 'af;'; Code: $00002061),
                                            (Name: 'afr;'; Code: $DD1ED835),
                                            (Name: 'agrave'; Code: $000000E0),
                                            (Name: 'alefsym;'; Code: $00002135),
                                            (Name: 'aleph;'; Code: $00002135),
                                            (Name: 'alpha;'; Code: $000003B1),
                                            (Name: 'amacr;'; Code: $00000101),
                                            (Name: 'amalg;'; Code: $00002A3F),
                                            (Name: 'amp'; Code: $00000026),
                                            (Name: 'and;'; Code: $00002227),
                                            (Name: 'andand;'; Code: $00002A55),
                                            (Name: 'andd;'; Code: $00002A5C),
                                            (Name: 'andslope;'; Code: $00002A58),
                                            (Name: 'andv;'; Code: $00002A5A),
                                            (Name: 'ang;'; Code: $00002220),
                                            (Name: 'ange;'; Code: $000029A4),
                                            (Name: 'angle;'; Code: $00002220),
                                            (Name: 'angmsd;'; Code: $00002221),
                                            (Name: 'angmsdaa;'; Code: $000029A8),
                                            (Name: 'angmsdab;'; Code: $000029A9),
                                            (Name: 'angmsdac;'; Code: $000029AA),
                                            (Name: 'angmsdad;'; Code: $000029AB),
                                            (Name: 'angmsdae;'; Code: $000029AC),
                                            (Name: 'angmsdaf;'; Code: $000029AD),
                                            (Name: 'angmsdag;'; Code: $000029AE),
                                            (Name: 'angmsdah;'; Code: $000029AF),
                                            (Name: 'angrt;'; Code: $0000221F),
                                            (Name: 'angrtvb;'; Code: $000022BE),
                                            (Name: 'angrtvbd;'; Code: $0000299D),
                                            (Name: 'angsph;'; Code: $00002222),
                                            (Name: 'angst;'; Code: $000000C5),
                                            (Name: 'angzarr;'; Code: $0000237C),
                                            (Name: 'aogon;'; Code: $00000105),
                                            (Name: 'aopf;'; Code: $DD52D835),
                                            (Name: 'ap;'; Code: $00002248),
                                            (Name: 'apE;'; Code: $00002A70),
                                            (Name: 'apacir;'; Code: $00002A6F),
                                            (Name: 'ape;'; Code: $0000224A),
                                            (Name: 'apid;'; Code: $0000224B),
                                            (Name: 'apos;'; Code: $00000027),
                                            (Name: 'approx;'; Code: $00002248),
                                            (Name: 'approxeq;'; Code: $0000224A),
                                            (Name: 'aring'; Code: $000000E5),
                                            (Name: 'ascr;'; Code: $DCB6D835),
                                            (Name: 'ast;'; Code: $0000002A),
                                            (Name: 'asymp;'; Code: $00002248),
                                            (Name: 'asympeq;'; Code: $0000224D),
                                            (Name: 'atilde'; Code: $000000E3),
                                            (Name: 'auml'; Code: $000000E4),
                                            (Name: 'awconint;'; Code: $00002233),
                                            (Name: 'awint;'; Code: $00002A11),
                                            (Name: 'bNot;'; Code: $00002AED),
                                            (Name: 'backcong;'; Code: $0000224C),
                                            (Name: 'backepsilon;'; Code: $000003F6),
                                            (Name: 'backprime;'; Code: $00002035),
                                            (Name: 'backsim;'; Code: $0000223D),
                                            (Name: 'backsimeq;'; Code: $000022CD),
                                            (Name: 'barvee;'; Code: $000022BD),
                                            (Name: 'barwed;'; Code: $00002305),
                                            (Name: 'barwedge;'; Code: $00002305),
                                            (Name: 'bbrk;'; Code: $000023B5),
                                            (Name: 'bbrktbrk;'; Code: $000023B6),
                                            (Name: 'bcong;'; Code: $0000224C),
                                            (Name: 'bcy;'; Code: $00000431),
                                            (Name: 'bdquo;'; Code: $0000201E),
                                            (Name: 'becaus;'; Code: $00002235),
                                            (Name: 'because;'; Code: $00002235),
                                            (Name: 'bemptyv;'; Code: $000029B0),
                                            (Name: 'bepsi;'; Code: $000003F6),
                                            (Name: 'bernou;'; Code: $0000212C),
                                            (Name: 'beta;'; Code: $000003B2),
                                            (Name: 'beth;'; Code: $00002136),
                                            (Name: 'between;'; Code: $0000226C),
                                            (Name: 'bfr;'; Code: $DD1FD835),
                                            (Name: 'bigcap;'; Code: $000022C2),
                                            (Name: 'bigcirc;'; Code: $000025EF),
                                            (Name: 'bigcup;'; Code: $000022C3),
                                            (Name: 'bigodot;'; Code: $00002A00),
                                            (Name: 'bigoplus;'; Code: $00002A01),
                                            (Name: 'bigotimes;'; Code: $00002A02),
                                            (Name: 'bigsqcup;'; Code: $00002A06),
                                            (Name: 'bigstar;'; Code: $00002605),
                                            (Name: 'bigtriangledown;'; Code: $000025BD),
                                            (Name: 'bigtriangleup;'; Code: $000025B3),
                                            (Name: 'biguplus;'; Code: $00002A04),
                                            (Name: 'bigvee;'; Code: $000022C1),
                                            (Name: 'bigwedge;'; Code: $000022C0),
                                            (Name: 'bkarow;'; Code: $0000290D),
                                            (Name: 'blacklozenge;'; Code: $000029EB),
                                            (Name: 'blacksquare;'; Code: $000025AA),
                                            (Name: 'blacktriangle;'; Code: $000025B4),
                                            (Name: 'blacktriangledown;'; Code: $000025BE),
                                            (Name: 'blacktriangleleft;'; Code: $000025C2),
                                            (Name: 'blacktriangleright;'; Code: $000025B8),
                                            (Name: 'blank;'; Code: $00002423),
                                            (Name: 'blk12;'; Code: $00002592),
                                            (Name: 'blk14;'; Code: $00002591),
                                            (Name: 'blk34;'; Code: $00002593),
                                            (Name: 'block;'; Code: $00002588),
                                            (Name: 'bne;'; Code: $20E5003D),
                                            (Name: 'bnequiv;'; Code: $20E52261),
                                            (Name: 'bnot;'; Code: $00002310),
                                            (Name: 'bopf;'; Code: $DD53D835),
                                            (Name: 'bot;'; Code: $000022A5),
                                            (Name: 'bottom;'; Code: $000022A5),
                                            (Name: 'bowtie;'; Code: $000022C8),
                                            (Name: 'boxDL;'; Code: $00002557),
                                            (Name: 'boxDR;'; Code: $00002554),
                                            (Name: 'boxDl;'; Code: $00002556),
                                            (Name: 'boxDr;'; Code: $00002553),
                                            (Name: 'boxH;'; Code: $00002550),
                                            (Name: 'boxHD;'; Code: $00002566),
                                            (Name: 'boxHU;'; Code: $00002569),
                                            (Name: 'boxHd;'; Code: $00002564),
                                            (Name: 'boxHu;'; Code: $00002567),
                                            (Name: 'boxUL;'; Code: $0000255D),
                                            (Name: 'boxUR;'; Code: $0000255A),
                                            (Name: 'boxUl;'; Code: $0000255C),
                                            (Name: 'boxUr;'; Code: $00002559),
                                            (Name: 'boxV;'; Code: $00002551),
                                            (Name: 'boxVH;'; Code: $0000256C),
                                            (Name: 'boxVL;'; Code: $00002563),
                                            (Name: 'boxVR;'; Code: $00002560),
                                            (Name: 'boxVh;'; Code: $0000256B),
                                            (Name: 'boxVl;'; Code: $00002562),
                                            (Name: 'boxVr;'; Code: $0000255F),
                                            (Name: 'boxbox;'; Code: $000029C9),
                                            (Name: 'boxdL;'; Code: $00002555),
                                            (Name: 'boxdR;'; Code: $00002552),
                                            (Name: 'boxdl;'; Code: $00002510),
                                            (Name: 'boxdr;'; Code: $0000250C),
                                            (Name: 'boxh;'; Code: $00002500),
                                            (Name: 'boxhD;'; Code: $00002565),
                                            (Name: 'boxhU;'; Code: $00002568),
                                            (Name: 'boxhd;'; Code: $0000252C),
                                            (Name: 'boxhu;'; Code: $00002534),
                                            (Name: 'boxminus;'; Code: $0000229F),
                                            (Name: 'boxplus;'; Code: $0000229E),
                                            (Name: 'boxtimes;'; Code: $000022A0),
                                            (Name: 'boxuL;'; Code: $0000255B),
                                            (Name: 'boxuR;'; Code: $00002558),
                                            (Name: 'boxul;'; Code: $00002518),
                                            (Name: 'boxur;'; Code: $00002514),
                                            (Name: 'boxv;'; Code: $00002502),
                                            (Name: 'boxvH;'; Code: $0000256A),
                                            (Name: 'boxvL;'; Code: $00002561),
                                            (Name: 'boxvR;'; Code: $0000255E),
                                            (Name: 'boxvh;'; Code: $0000253C),
                                            (Name: 'boxvl;'; Code: $00002524),
                                            (Name: 'boxvr;'; Code: $0000251C),
                                            (Name: 'bprime;'; Code: $00002035),
                                            (Name: 'breve;'; Code: $000002D8),
                                            (Name: 'brvbar'; Code: $000000A6),
                                            (Name: 'bscr;'; Code: $DCB7D835),
                                            (Name: 'bsemi;'; Code: $0000204F),
                                            (Name: 'bsim;'; Code: $0000223D),
                                            (Name: 'bsime;'; Code: $000022CD),
                                            (Name: 'bsol;'; Code: $0000005C),
                                            (Name: 'bsolb;'; Code: $000029C5),
                                            (Name: 'bsolhsub;'; Code: $000027C8),
                                            (Name: 'bull;'; Code: $00002022),
                                            (Name: 'bullet;'; Code: $00002022),
                                            (Name: 'bump;'; Code: $0000224E),
                                            (Name: 'bumpE;'; Code: $00002AAE),
                                            (Name: 'bumpe;'; Code: $0000224F),
                                            (Name: 'bumpeq;'; Code: $0000224F),
                                            (Name: 'cacute;'; Code: $00000107),
                                            (Name: 'cap;'; Code: $00002229),
                                            (Name: 'capand;'; Code: $00002A44),
                                            (Name: 'capbrcup;'; Code: $00002A49),
                                            (Name: 'capcap;'; Code: $00002A4B),
                                            (Name: 'capcup;'; Code: $00002A47),
                                            (Name: 'capdot;'; Code: $00002A40),
                                            (Name: 'caps;'; Code: $FE002229),
                                            (Name: 'caret;'; Code: $00002041),
                                            (Name: 'caron;'; Code: $000002C7),
                                            (Name: 'ccaps;'; Code: $00002A4D),
                                            (Name: 'ccaron;'; Code: $0000010D),
                                            (Name: 'ccedil'; Code: $000000E7),
                                            (Name: 'ccirc;'; Code: $00000109),
                                            (Name: 'ccups;'; Code: $00002A4C),
                                            (Name: 'ccupssm;'; Code: $00002A50),
                                            (Name: 'cdot;'; Code: $0000010B),
                                            (Name: 'cedil'; Code: $000000B8),
                                            (Name: 'cemptyv;'; Code: $000029B2),
                                            (Name: 'cent'; Code: $000000A2),
                                            (Name: 'centerdot;'; Code: $000000B7),
                                            (Name: 'cfr;'; Code: $DD20D835),
                                            (Name: 'chcy;'; Code: $00000447),
                                            (Name: 'check;'; Code: $00002713),
                                            (Name: 'checkmark;'; Code: $00002713),
                                            (Name: 'chi;'; Code: $000003C7),
                                            (Name: 'cir;'; Code: $000025CB),
                                            (Name: 'cirE;'; Code: $000029C3),
                                            (Name: 'circ;'; Code: $000002C6),
                                            (Name: 'circeq;'; Code: $00002257),
                                            (Name: 'circlearrowleft;'; Code: $000021BA),
                                            (Name: 'circlearrowright;'; Code: $000021BB),
                                            (Name: 'circledR;'; Code: $000000AE),
                                            (Name: 'circledS;'; Code: $000024C8),
                                            (Name: 'circledast;'; Code: $0000229B),
                                            (Name: 'circledcirc;'; Code: $0000229A),
                                            (Name: 'circleddash;'; Code: $0000229D),
                                            (Name: 'cire;'; Code: $00002257),
                                            (Name: 'cirfnint;'; Code: $00002A10),
                                            (Name: 'cirmid;'; Code: $00002AEF),
                                            (Name: 'cirscir;'; Code: $000029C2),
                                            (Name: 'clubs;'; Code: $00002663),
                                            (Name: 'clubsuit;'; Code: $00002663),
                                            (Name: 'colon;'; Code: $0000003A),
                                            (Name: 'colone;'; Code: $00002254),
                                            (Name: 'coloneq;'; Code: $00002254),
                                            (Name: 'comma;'; Code: $0000002C),
                                            (Name: 'commat;'; Code: $00000040),
                                            (Name: 'comp;'; Code: $00002201),
                                            (Name: 'compfn;'; Code: $00002218),
                                            (Name: 'complement;'; Code: $00002201),
                                            (Name: 'complexes;'; Code: $00002102),
                                            (Name: 'cong;'; Code: $00002245),
                                            (Name: 'congdot;'; Code: $00002A6D),
                                            (Name: 'conint;'; Code: $0000222E),
                                            (Name: 'copf;'; Code: $DD54D835),
                                            (Name: 'coprod;'; Code: $00002210),
                                            (Name: 'copy'; Code: $000000A9),
                                            (Name: 'copysr;'; Code: $00002117),
                                            (Name: 'crarr;'; Code: $000021B5),
                                            (Name: 'cross;'; Code: $00002717),
                                            (Name: 'cscr;'; Code: $DCB8D835),
                                            (Name: 'csub;'; Code: $00002ACF),
                                            (Name: 'csube;'; Code: $00002AD1),
                                            (Name: 'csup;'; Code: $00002AD0),
                                            (Name: 'csupe;'; Code: $00002AD2),
                                            (Name: 'ctdot;'; Code: $000022EF),
                                            (Name: 'cudarrl;'; Code: $00002938),
                                            (Name: 'cudarrr;'; Code: $00002935),
                                            (Name: 'cuepr;'; Code: $000022DE),
                                            (Name: 'cuesc;'; Code: $000022DF),
                                            (Name: 'cularr;'; Code: $000021B6),
                                            (Name: 'cularrp;'; Code: $0000293D),
                                            (Name: 'cup;'; Code: $0000222A),
                                            (Name: 'cupbrcap;'; Code: $00002A48),
                                            (Name: 'cupcap;'; Code: $00002A46),
                                            (Name: 'cupcup;'; Code: $00002A4A),
                                            (Name: 'cupdot;'; Code: $0000228D),
                                            (Name: 'cupor;'; Code: $00002A45),
                                            (Name: 'cups;'; Code: $FE00222A),
                                            (Name: 'curarr;'; Code: $000021B7),
                                            (Name: 'curarrm;'; Code: $0000293C),
                                            (Name: 'curlyeqprec;'; Code: $000022DE),
                                            (Name: 'curlyeqsucc;'; Code: $000022DF),
                                            (Name: 'curlyvee;'; Code: $000022CE),
                                            (Name: 'curlywedge;'; Code: $000022CF),
                                            (Name: 'curren'; Code: $000000A4),
                                            (Name: 'curvearrowleft;'; Code: $000021B6),
                                            (Name: 'curvearrowright;'; Code: $000021B7),
                                            (Name: 'cuvee;'; Code: $000022CE),
                                            (Name: 'cuwed;'; Code: $000022CF),
                                            (Name: 'cwconint;'; Code: $00002232),
                                            (Name: 'cwint;'; Code: $00002231),
                                            (Name: 'cylcty;'; Code: $0000232D),
                                            (Name: 'dArr;'; Code: $000021D3),
                                            (Name: 'dHar;'; Code: $00002965),
                                            (Name: 'dagger;'; Code: $00002020),
                                            (Name: 'daleth;'; Code: $00002138),
                                            (Name: 'darr;'; Code: $00002193),
                                            (Name: 'dash;'; Code: $00002010),
                                            (Name: 'dashv;'; Code: $000022A3),
                                            (Name: 'dbkarow;'; Code: $0000290F),
                                            (Name: 'dblac;'; Code: $000002DD),
                                            (Name: 'dcaron;'; Code: $0000010F),
                                            (Name: 'dcy;'; Code: $00000434),
                                            (Name: 'dd;'; Code: $00002146),
                                            (Name: 'ddagger;'; Code: $00002021),
                                            (Name: 'ddarr;'; Code: $000021CA),
                                            (Name: 'ddotseq;'; Code: $00002A77),
                                            (Name: 'deg'; Code: $000000B0),
                                            (Name: 'delta;'; Code: $000003B4),
                                            (Name: 'demptyv;'; Code: $000029B1),
                                            (Name: 'dfisht;'; Code: $0000297F),
                                            (Name: 'dfr;'; Code: $DD21D835),
                                            (Name: 'dharl;'; Code: $000021C3),
                                            (Name: 'dharr;'; Code: $000021C2),
                                            (Name: 'diam;'; Code: $000022C4),
                                            (Name: 'diamond;'; Code: $000022C4),
                                            (Name: 'diamondsuit;'; Code: $00002666),
                                            (Name: 'diams;'; Code: $00002666),
                                            (Name: 'die;'; Code: $000000A8),
                                            (Name: 'digamma;'; Code: $000003DD),
                                            (Name: 'disin;'; Code: $000022F2),
                                            (Name: 'div;'; Code: $000000F7),
                                            (Name: 'divide'; Code: $000000F7),
                                            (Name: 'divideontimes;'; Code: $000022C7),
                                            (Name: 'divonx;'; Code: $000022C7),
                                            (Name: 'djcy;'; Code: $00000452),
                                            (Name: 'dlcorn;'; Code: $0000231E),
                                            (Name: 'dlcrop;'; Code: $0000230D),
                                            (Name: 'dollar;'; Code: $00000024),
                                            (Name: 'dopf;'; Code: $DD55D835),
                                            (Name: 'dot;'; Code: $000002D9),
                                            (Name: 'doteq;'; Code: $00002250),
                                            (Name: 'doteqdot;'; Code: $00002251),
                                            (Name: 'dotminus;'; Code: $00002238),
                                            (Name: 'dotplus;'; Code: $00002214),
                                            (Name: 'dotsquare;'; Code: $000022A1),
                                            (Name: 'doublebarwedge;'; Code: $00002306),
                                            (Name: 'downarrow;'; Code: $00002193),
                                            (Name: 'downdownarrows;'; Code: $000021CA),
                                            (Name: 'downharpoonleft;'; Code: $000021C3),
                                            (Name: 'downharpoonright;'; Code: $000021C2),
                                            (Name: 'drbkarow;'; Code: $00002910),
                                            (Name: 'drcorn;'; Code: $0000231F),
                                            (Name: 'drcrop;'; Code: $0000230C),
                                            (Name: 'dscr;'; Code: $DCB9D835),
                                            (Name: 'dscy;'; Code: $00000455),
                                            (Name: 'dsol;'; Code: $000029F6),
                                            (Name: 'dstrok;'; Code: $00000111),
                                            (Name: 'dtdot;'; Code: $000022F1),
                                            (Name: 'dtri;'; Code: $000025BF),
                                            (Name: 'dtrif;'; Code: $000025BE),
                                            (Name: 'duarr;'; Code: $000021F5),
                                            (Name: 'duhar;'; Code: $0000296F),
                                            (Name: 'dwangle;'; Code: $000029A6),
                                            (Name: 'dzcy;'; Code: $0000045F),
                                            (Name: 'dzigrarr;'; Code: $000027FF),
                                            (Name: 'eDDot;'; Code: $00002A77),
                                            (Name: 'eDot;'; Code: $00002251),
                                            (Name: 'eacute'; Code: $000000E9),
                                            (Name: 'easter;'; Code: $00002A6E),
                                            (Name: 'ecaron;'; Code: $0000011B),
                                            (Name: 'ecir;'; Code: $00002256),
                                            (Name: 'ecirc'; Code: $000000EA),
                                            (Name: 'ecolon;'; Code: $00002255),
                                            (Name: 'ecy;'; Code: $0000044D),
                                            (Name: 'edot;'; Code: $00000117),
                                            (Name: 'ee;'; Code: $00002147),
                                            (Name: 'efDot;'; Code: $00002252),
                                            (Name: 'efr;'; Code: $DD22D835),
                                            (Name: 'eg;'; Code: $00002A9A),
                                            (Name: 'egrave'; Code: $000000E8),
                                            (Name: 'egs;'; Code: $00002A96),
                                            (Name: 'egsdot;'; Code: $00002A98),
                                            (Name: 'el;'; Code: $00002A99),
                                            (Name: 'elinters;'; Code: $000023E7),
                                            (Name: 'ell;'; Code: $00002113),
                                            (Name: 'els;'; Code: $00002A95),
                                            (Name: 'elsdot;'; Code: $00002A97),
                                            (Name: 'emacr;'; Code: $00000113),
                                            (Name: 'empty;'; Code: $00002205),
                                            (Name: 'emptyset;'; Code: $00002205),
                                            (Name: 'emptyv;'; Code: $00002205),
                                            (Name: 'emsp13;'; Code: $00002004),
                                            (Name: 'emsp14;'; Code: $00002005),
                                            (Name: 'emsp;'; Code: $00002003),
                                            (Name: 'eng;'; Code: $0000014B),
                                            (Name: 'ensp;'; Code: $00002002),
                                            (Name: 'eogon;'; Code: $00000119),
                                            (Name: 'eopf;'; Code: $DD56D835),
                                            (Name: 'epar;'; Code: $000022D5),
                                            (Name: 'eparsl;'; Code: $000029E3),
                                            (Name: 'eplus;'; Code: $00002A71),
                                            (Name: 'epsi;'; Code: $000003B5),
                                            (Name: 'epsilon;'; Code: $000003B5),
                                            (Name: 'epsiv;'; Code: $000003F5),
                                            (Name: 'eqcirc;'; Code: $00002256),
                                            (Name: 'eqcolon;'; Code: $00002255),
                                            (Name: 'eqsim;'; Code: $00002242),
                                            (Name: 'eqslantgtr;'; Code: $00002A96),
                                            (Name: 'eqslantless;'; Code: $00002A95),
                                            (Name: 'equals;'; Code: $0000003D),
                                            (Name: 'equest;'; Code: $0000225F),
                                            (Name: 'equiv;'; Code: $00002261),
                                            (Name: 'equivDD;'; Code: $00002A78),
                                            (Name: 'eqvparsl;'; Code: $000029E5),
                                            (Name: 'erDot;'; Code: $00002253),
                                            (Name: 'erarr;'; Code: $00002971),
                                            (Name: 'escr;'; Code: $0000212F),
                                            (Name: 'esdot;'; Code: $00002250),
                                            (Name: 'esim;'; Code: $00002242),
                                            (Name: 'eta;'; Code: $000003B7),
                                            (Name: 'eth'; Code: $000000F0),
                                            (Name: 'euml'; Code: $000000EB),
                                            (Name: 'euro;'; Code: $000020AC),
                                            (Name: 'excl;'; Code: $00000021),
                                            (Name: 'exist;'; Code: $00002203),
                                            (Name: 'expectation;'; Code: $00002130),
                                            (Name: 'exponentiale;'; Code: $00002147),
                                            (Name: 'fallingdotseq;'; Code: $00002252),
                                            (Name: 'fcy;'; Code: $00000444),
                                            (Name: 'female;'; Code: $00002640),
                                            (Name: 'ffilig;'; Code: $0000FB03),
                                            (Name: 'fflig;'; Code: $0000FB00),
                                            (Name: 'ffllig;'; Code: $0000FB04),
                                            (Name: 'ffr;'; Code: $DD23D835),
                                            (Name: 'filig;'; Code: $0000FB01),
                                            (Name: 'fjlig;'; Code: $006A0066),
                                            (Name: 'flat;'; Code: $0000266D),
                                            (Name: 'fllig;'; Code: $0000FB02),
                                            (Name: 'fltns;'; Code: $000025B1),
                                            (Name: 'fnof;'; Code: $00000192),
                                            (Name: 'fopf;'; Code: $DD57D835),
                                            (Name: 'forall;'; Code: $00002200),
                                            (Name: 'fork;'; Code: $000022D4),
                                            (Name: 'forkv;'; Code: $00002AD9),
                                            (Name: 'fpartint;'; Code: $00002A0D),
                                            (Name: 'frac12'; Code: $000000BD),
                                            (Name: 'frac13;'; Code: $00002153),
                                            (Name: 'frac14'; Code: $000000BC),
                                            (Name: 'frac15;'; Code: $00002155),
                                            (Name: 'frac16;'; Code: $00002159),
                                            (Name: 'frac18;'; Code: $0000215B),
                                            (Name: 'frac23;'; Code: $00002154),
                                            (Name: 'frac25;'; Code: $00002156),
                                            (Name: 'frac34'; Code: $000000BE),
                                            (Name: 'frac35;'; Code: $00002157),
                                            (Name: 'frac38;'; Code: $0000215C),
                                            (Name: 'frac45;'; Code: $00002158),
                                            (Name: 'frac56;'; Code: $0000215A),
                                            (Name: 'frac58;'; Code: $0000215D),
                                            (Name: 'frac78;'; Code: $0000215E),
                                            (Name: 'frasl;'; Code: $00002044),
                                            (Name: 'frown;'; Code: $00002322),
                                            (Name: 'fscr;'; Code: $DCBBD835),
                                            (Name: 'gE;'; Code: $00002267),
                                            (Name: 'gEl;'; Code: $00002A8C),
                                            (Name: 'gacute;'; Code: $000001F5),
                                            (Name: 'gamma;'; Code: $000003B3),
                                            (Name: 'gammad;'; Code: $000003DD),
                                            (Name: 'gap;'; Code: $00002A86),
                                            (Name: 'gbreve;'; Code: $0000011F),
                                            (Name: 'gcirc;'; Code: $0000011D),
                                            (Name: 'gcy;'; Code: $00000433),
                                            (Name: 'gdot;'; Code: $00000121),
                                            (Name: 'ge;'; Code: $00002265),
                                            (Name: 'gel;'; Code: $000022DB),
                                            (Name: 'geq;'; Code: $00002265),
                                            (Name: 'geqq;'; Code: $00002267),
                                            (Name: 'geqslant;'; Code: $00002A7E),
                                            (Name: 'ges;'; Code: $00002A7E),
                                            (Name: 'gescc;'; Code: $00002AA9),
                                            (Name: 'gesdot;'; Code: $00002A80),
                                            (Name: 'gesdoto;'; Code: $00002A82),
                                            (Name: 'gesdotol;'; Code: $00002A84),
                                            (Name: 'gesl;'; Code: $FE0022DB),
                                            (Name: 'gesles;'; Code: $00002A94),
                                            (Name: 'gfr;'; Code: $DD24D835),
                                            (Name: 'gg;'; Code: $0000226B),
                                            (Name: 'ggg;'; Code: $000022D9),
                                            (Name: 'gimel;'; Code: $00002137),
                                            (Name: 'gjcy;'; Code: $00000453),
                                            (Name: 'gl;'; Code: $00002277),
                                            (Name: 'glE;'; Code: $00002A92),
                                            (Name: 'gla;'; Code: $00002AA5),
                                            (Name: 'glj;'; Code: $00002AA4),
                                            (Name: 'gnE;'; Code: $00002269),
                                            (Name: 'gnap;'; Code: $00002A8A),
                                            (Name: 'gnapprox;'; Code: $00002A8A),
                                            (Name: 'gne;'; Code: $00002A88),
                                            (Name: 'gneq;'; Code: $00002A88),
                                            (Name: 'gneqq;'; Code: $00002269),
                                            (Name: 'gnsim;'; Code: $000022E7),
                                            (Name: 'gopf;'; Code: $DD58D835),
                                            (Name: 'grave;'; Code: $00000060),
                                            (Name: 'gscr;'; Code: $0000210A),
                                            (Name: 'gsim;'; Code: $00002273),
                                            (Name: 'gsime;'; Code: $00002A8E),
                                            (Name: 'gsiml;'; Code: $00002A90),
                                            (Name: 'gt'; Code: $0000003E),
                                            (Name: 'gtcc;'; Code: $00002AA7),
                                            (Name: 'gtcir;'; Code: $00002A7A),
                                            (Name: 'gtdot;'; Code: $000022D7),
                                            (Name: 'gtlPar;'; Code: $00002995),
                                            (Name: 'gtquest;'; Code: $00002A7C),
                                            (Name: 'gtrapprox;'; Code: $00002A86),
                                            (Name: 'gtrarr;'; Code: $00002978),
                                            (Name: 'gtrdot;'; Code: $000022D7),
                                            (Name: 'gtreqless;'; Code: $000022DB),
                                            (Name: 'gtreqqless;'; Code: $00002A8C),
                                            (Name: 'gtrless;'; Code: $00002277),
                                            (Name: 'gtrsim;'; Code: $00002273),
                                            (Name: 'gvertneqq;'; Code: $FE002269),
                                            (Name: 'gvnE;'; Code: $FE002269),
                                            (Name: 'hArr;'; Code: $000021D4),
                                            (Name: 'hairsp;'; Code: $0000200A),
                                            (Name: 'half;'; Code: $000000BD),
                                            (Name: 'hamilt;'; Code: $0000210B),
                                            (Name: 'hardcy;'; Code: $0000044A),
                                            (Name: 'harr;'; Code: $00002194),
                                            (Name: 'harrcir;'; Code: $00002948),
                                            (Name: 'harrw;'; Code: $000021AD),
                                            (Name: 'hbar;'; Code: $0000210F),
                                            (Name: 'hcirc;'; Code: $00000125),
                                            (Name: 'hearts;'; Code: $00002665),
                                            (Name: 'heartsuit;'; Code: $00002665),
                                            (Name: 'hellip;'; Code: $00002026),
                                            (Name: 'hercon;'; Code: $000022B9),
                                            (Name: 'hfr;'; Code: $DD25D835),
                                            (Name: 'hksearow;'; Code: $00002925),
                                            (Name: 'hkswarow;'; Code: $00002926),
                                            (Name: 'hoarr;'; Code: $000021FF),
                                            (Name: 'homtht;'; Code: $0000223B),
                                            (Name: 'hookleftarrow;'; Code: $000021A9),
                                            (Name: 'hookrightarrow;'; Code: $000021AA),
                                            (Name: 'hopf;'; Code: $DD59D835),
                                            (Name: 'horbar;'; Code: $00002015),
                                            (Name: 'hscr;'; Code: $DCBDD835),
                                            (Name: 'hslash;'; Code: $0000210F),
                                            (Name: 'hstrok;'; Code: $00000127),
                                            (Name: 'hybull;'; Code: $00002043),
                                            (Name: 'hyphen;'; Code: $00002010),
                                            (Name: 'iacute'; Code: $000000ED),
                                            (Name: 'ic;'; Code: $00002063),
                                            (Name: 'icirc'; Code: $000000EE),
                                            (Name: 'icy;'; Code: $00000438),
                                            (Name: 'iecy;'; Code: $00000435),
                                            (Name: 'iexcl'; Code: $000000A1),
                                            (Name: 'iff;'; Code: $000021D4),
                                            (Name: 'ifr;'; Code: $DD26D835),
                                            (Name: 'igrave'; Code: $000000EC),
                                            (Name: 'ii;'; Code: $00002148),
                                            (Name: 'iiiint;'; Code: $00002A0C),
                                            (Name: 'iiint;'; Code: $0000222D),
                                            (Name: 'iinfin;'; Code: $000029DC),
                                            (Name: 'iiota;'; Code: $00002129),
                                            (Name: 'ijlig;'; Code: $00000133),
                                            (Name: 'imacr;'; Code: $0000012B),
                                            (Name: 'image;'; Code: $00002111),
                                            (Name: 'imagline;'; Code: $00002110),
                                            (Name: 'imagpart;'; Code: $00002111),
                                            (Name: 'imath;'; Code: $00000131),
                                            (Name: 'imof;'; Code: $000022B7),
                                            (Name: 'imped;'; Code: $000001B5),
                                            (Name: 'in;'; Code: $00002208),
                                            (Name: 'incare;'; Code: $00002105),
                                            (Name: 'infin;'; Code: $0000221E),
                                            (Name: 'infintie;'; Code: $000029DD),
                                            (Name: 'inodot;'; Code: $00000131),
                                            (Name: 'int;'; Code: $0000222B),
                                            (Name: 'intcal;'; Code: $000022BA),
                                            (Name: 'integers;'; Code: $00002124),
                                            (Name: 'intercal;'; Code: $000022BA),
                                            (Name: 'intlarhk;'; Code: $00002A17),
                                            (Name: 'intprod;'; Code: $00002A3C),
                                            (Name: 'iocy;'; Code: $00000451),
                                            (Name: 'iogon;'; Code: $0000012F),
                                            (Name: 'iopf;'; Code: $DD5AD835),
                                            (Name: 'iota;'; Code: $000003B9),
                                            (Name: 'iprod;'; Code: $00002A3C),
                                            (Name: 'iquest'; Code: $000000BF),
                                            (Name: 'iscr;'; Code: $DCBED835),
                                            (Name: 'isin;'; Code: $00002208),
                                            (Name: 'isinE;'; Code: $000022F9),
                                            (Name: 'isindot;'; Code: $000022F5),
                                            (Name: 'isins;'; Code: $000022F4),
                                            (Name: 'isinsv;'; Code: $000022F3),
                                            (Name: 'isinv;'; Code: $00002208),
                                            (Name: 'it;'; Code: $00002062),
                                            (Name: 'itilde;'; Code: $00000129),
                                            (Name: 'iukcy;'; Code: $00000456),
                                            (Name: 'iuml'; Code: $000000EF),
                                            (Name: 'jcirc;'; Code: $00000135),
                                            (Name: 'jcy;'; Code: $00000439),
                                            (Name: 'jfr;'; Code: $DD27D835),
                                            (Name: 'jmath;'; Code: $00000237),
                                            (Name: 'jopf;'; Code: $DD5BD835),
                                            (Name: 'jscr;'; Code: $DCBFD835),
                                            (Name: 'jsercy;'; Code: $00000458),
                                            (Name: 'jukcy;'; Code: $00000454),
                                            (Name: 'kappa;'; Code: $000003BA),
                                            (Name: 'kappav;'; Code: $000003F0),
                                            (Name: 'kcedil;'; Code: $00000137),
                                            (Name: 'kcy;'; Code: $0000043A),
                                            (Name: 'kfr;'; Code: $DD28D835),
                                            (Name: 'kgreen;'; Code: $00000138),
                                            (Name: 'khcy;'; Code: $00000445),
                                            (Name: 'kjcy;'; Code: $0000045C),
                                            (Name: 'kopf;'; Code: $DD5CD835),
                                            (Name: 'kscr;'; Code: $DCC0D835),
                                            (Name: 'lAarr;'; Code: $000021DA),
                                            (Name: 'lArr;'; Code: $000021D0),
                                            (Name: 'lAtail;'; Code: $0000291B),     
                                            (Name: 'lBarr;'; Code: $0000290E),
                                            (Name: 'lE;'; Code: $00002266),       
                                            (Name: 'lEg;'; Code: $00002A8B),      
                                            (Name: 'lHar;'; Code: $00002962),
                                            (Name: 'lacute;'; Code: $0000013A),
                                            (Name: 'laemptyv;'; Code: $000029B4),
                                            (Name: 'lagran;'; Code: $00002112),
                                            (Name: 'lambda;'; Code: $000003BB),
                                            (Name: 'lang;'; Code: $000027E8),
                                            (Name: 'langd;'; Code: $00002991),
                                            (Name: 'langle;'; Code: $000027E8),
                                            (Name: 'lap;'; Code: $00002A85),
                                            (Name: 'laquo'; Code: $000000AB),
                                            (Name: 'larr;'; Code: $00002190),
                                            (Name: 'larrb;'; Code: $000021E4),
                                            (Name: 'larrbfs;'; Code: $0000291F),
                                            (Name: 'larrfs;'; Code: $0000291D),
                                            (Name: 'larrhk;'; Code: $000021A9),
                                            (Name: 'larrlp;'; Code: $000021AB),
                                            (Name: 'larrpl;'; Code: $00002939),
                                            (Name: 'larrsim;'; Code: $00002973),
                                            (Name: 'larrtl;'; Code: $000021A2),
                                            (Name: 'lat;'; Code: $00002AAB),
                                            (Name: 'latail;'; Code: $00002919),
                                            (Name: 'late;'; Code: $00002AAD),
                                            (Name: 'lates;'; Code: $FE002AAD),
                                            (Name: 'lbarr;'; Code: $0000290C),
                                            (Name: 'lbbrk;'; Code: $00002772),
                                            (Name: 'lbrace;'; Code: $0000007B),
                                            (Name: 'lbrack;'; Code: $0000005B),
                                            (Name: 'lbrke;'; Code: $0000298B),
                                            (Name: 'lbrksld;'; Code: $0000298F),
                                            (Name: 'lbrkslu;'; Code: $0000298D),
                                            (Name: 'lcaron;'; Code: $0000013E),
                                            (Name: 'lcedil;'; Code: $0000013C),
                                            (Name: 'lceil;'; Code: $00002308),
                                            (Name: 'lcub;'; Code: $0000007B),
                                            (Name: 'lcy;'; Code: $0000043B),
                                            (Name: 'ldca;'; Code: $00002936),
                                            (Name: 'ldquo;'; Code: $0000201C),
                                            (Name: 'ldquor;'; Code: $0000201E),
                                            (Name: 'ldrdhar;'; Code: $00002967),
                                            (Name: 'ldrushar;'; Code: $0000294B),
                                            (Name: 'ldsh;'; Code: $000021B2),
                                            (Name: 'le;'; Code: $00002264),
                                            (Name: 'leftarrow;'; Code: $00002190),
                                            (Name: 'leftarrowtail;'; Code: $000021A2),
                                            (Name: 'leftharpoondown;'; Code: $000021BD),
                                            (Name: 'leftharpoonup;'; Code: $000021BC),
                                            (Name: 'leftleftarrows;'; Code: $000021C7),
                                            (Name: 'leftrightarrow;'; Code: $00002194),
                                            (Name: 'leftrightarrows;'; Code: $000021C6),
                                            (Name: 'leftrightharpoons;'; Code: $000021CB),
                                            (Name: 'leftrightsquigarrow;'; Code: $000021AD),
                                            (Name: 'leftthreetimes;'; Code: $000022CB),
                                            (Name: 'leg;'; Code: $000022DA),
                                            (Name: 'leq;'; Code: $00002264),
                                            (Name: 'leqq;'; Code: $00002266),
                                            (Name: 'leqslant;'; Code: $00002A7D),
                                            (Name: 'les;'; Code: $00002A7D),
                                            (Name: 'lescc;'; Code: $00002AA8),
                                            (Name: 'lesdot;'; Code: $00002A7F),
                                            (Name: 'lesdoto;'; Code: $00002A81),
                                            (Name: 'lesdotor;'; Code: $00002A83),
                                            (Name: 'lesg;'; Code: $FE0022DA),
                                            (Name: 'lesges;'; Code: $00002A93),
                                            (Name: 'lessapprox;'; Code: $00002A85),
                                            (Name: 'lessdot;'; Code: $000022D6),
                                            (Name: 'lesseqgtr;'; Code: $000022DA),
                                            (Name: 'lesseqqgtr;'; Code: $00002A8B),
                                            (Name: 'lessgtr;'; Code: $00002276),
                                            (Name: 'lesssim;'; Code: $00002272),
                                            (Name: 'lfisht;'; Code: $0000297C),
                                            (Name: 'lfloor;'; Code: $0000230A),
                                            (Name: 'lfr;'; Code: $DD29D835),
                                            (Name: 'lg;'; Code: $00002276),
                                            (Name: 'lgE;'; Code: $00002A91),
                                            (Name: 'lhard;'; Code: $000021BD),
                                            (Name: 'lharu;'; Code: $000021BC),
                                            (Name: 'lharul;'; Code: $0000296A),
                                            (Name: 'lhblk;'; Code: $00002584),
                                            (Name: 'ljcy;'; Code: $00000459),
                                            (Name: 'll;'; Code: $0000226A),
                                            (Name: 'llarr;'; Code: $000021C7),
                                            (Name: 'llcorner;'; Code: $0000231E),
                                            (Name: 'llhard;'; Code: $0000296B),
                                            (Name: 'lltri;'; Code: $000025FA),
                                            (Name: 'lmidot;'; Code: $00000140),
                                            (Name: 'lmoust;'; Code: $000023B0),
                                            (Name: 'lmoustache;'; Code: $000023B0), 
                                            (Name: 'lnE;'; Code: $00002268),
                                            (Name: 'lnap;'; Code: $00002A89),
                                            (Name: 'lnapprox;'; Code: $00002A89),
                                            (Name: 'lne;'; Code: $00002A87),
                                            (Name: 'lneq;'; Code: $00002A87),
                                            (Name: 'lneqq;'; Code: $00002268),
                                            (Name: 'lnsim;'; Code: $000022E6),
                                            (Name: 'loang;'; Code: $000027EC),
                                            (Name: 'loarr;'; Code: $000021FD),
                                            (Name: 'lobrk;'; Code: $000027E6),
                                            (Name: 'longleftarrow;'; Code: $000027F5),
                                            (Name: 'longleftrightarrow;'; Code: $000027F7),
                                            (Name: 'longmapsto;'; Code: $000027FC),
                                            (Name: 'longrightarrow;'; Code: $000027F6),
                                            (Name: 'looparrowleft;'; Code: $000021AB),
                                            (Name: 'looparrowright;'; Code: $000021AC),
                                            (Name: 'lopar;'; Code: $00002985),
                                            (Name: 'lopf;'; Code: $DD5DD835),
                                            (Name: 'loplus;'; Code: $00002A2D),
                                            (Name: 'lotimes;'; Code: $00002A34),
                                            (Name: 'lowast;'; Code: $00002217),
                                            (Name: 'lowbar;'; Code: $0000005F),
                                            (Name: 'loz;'; Code: $000025CA),
                                            (Name: 'lozenge;'; Code: $000025CA),
                                            (Name: 'lozf;'; Code: $000029EB),
                                            (Name: 'lpar;'; Code: $00000028),
                                            (Name: 'lparlt;'; Code: $00002993),
                                            (Name: 'lrarr;'; Code: $000021C6),
                                            (Name: 'lrcorner;'; Code: $0000231F),
                                            (Name: 'lrhar;'; Code: $000021CB),
                                            (Name: 'lrhard;'; Code: $0000296D),
                                            (Name: 'lrm;'; Code: $0000200E),
                                            (Name: 'lrtri;'; Code: $000022BF),
                                            (Name: 'lsaquo;'; Code: $00002039),
                                            (Name: 'lscr;'; Code: $DCC1D835),
                                            (Name: 'lsh;'; Code: $000021B0),
                                            (Name: 'lsim;'; Code: $00002272),
                                            (Name: 'lsime;'; Code: $00002A8D),
                                            (Name: 'lsimg;'; Code: $00002A8F),
                                            (Name: 'lsqb;'; Code: $0000005B),
                                            (Name: 'lsquo;'; Code: $00002018),
                                            (Name: 'lsquor;'; Code: $0000201A),
                                            (Name: 'lstrok;'; Code: $00000142),
                                            (Name: 'lt'; Code: $0000003C),
                                            (Name: 'ltcc;'; Code: $00002AA6),
                                            (Name: 'ltcir;'; Code: $00002A79),
                                            (Name: 'ltdot;'; Code: $000022D6),
                                            (Name: 'lthree;'; Code: $000022CB),
                                            (Name: 'ltimes;'; Code: $000022C9),
                                            (Name: 'ltlarr;'; Code: $00002976),
                                            (Name: 'ltquest;'; Code: $00002A7B),
                                            (Name: 'ltrPar;'; Code: $00002996),
                                            (Name: 'ltri;'; Code: $000025C3),
                                            (Name: 'ltrie;'; Code: $000022B4),
                                            (Name: 'ltrif;'; Code: $000025C2),
                                            (Name: 'lurdshar;'; Code: $0000294A),
                                            (Name: 'luruhar;'; Code: $00002966),
                                            (Name: 'lvertneqq;'; Code: $FE002268),
                                            (Name: 'lvnE;'; Code: $FE002268),    
                                            (Name: 'mDDot;'; Code: $0000223A),
                                            (Name: 'macr'; Code: $000000AF),
                                            (Name: 'male;'; Code: $00002642),
                                            (Name: 'malt;'; Code: $00002720),
                                            (Name: 'maltese;'; Code: $00002720),
                                            (Name: 'map;'; Code: $000021A6),
                                            (Name: 'mapsto;'; Code: $000021A6),
                                            (Name: 'mapstodown;'; Code: $000021A7),
                                            (Name: 'mapstoleft;'; Code: $000021A4),
                                            (Name: 'mapstoup;'; Code: $000021A5),
                                            (Name: 'marker;'; Code: $000025AE),
                                            (Name: 'mcomma;'; Code: $00002A29),
                                            (Name: 'mcy;'; Code: $0000043C),
                                            (Name: 'mdash;'; Code: $00002014),
                                            (Name: 'measuredangle;'; Code: $00002221),
                                            (Name: 'mfr;'; Code: $DD2AD835),
                                            (Name: 'mho;'; Code: $00002127),
                                            (Name: 'micro'; Code: $000000B5),
                                            (Name: 'mid;'; Code: $00002223),
                                            (Name: 'midast;'; Code: $0000002A),
                                            (Name: 'midcir;'; Code: $00002AF0),
                                            (Name: 'middot'; Code: $000000B7),
                                            (Name: 'minus;'; Code: $00002212),
                                            (Name: 'minusb;'; Code: $0000229F),
                                            (Name: 'minusd;'; Code: $00002238),
                                            (Name: 'minusdu;'; Code: $00002A2A),
                                            (Name: 'mlcp;'; Code: $00002ADB),
                                            (Name: 'mldr;'; Code: $00002026),
                                            (Name: 'mnplus;'; Code: $00002213),
                                            (Name: 'models;'; Code: $000022A7),
                                            (Name: 'mopf;'; Code: $DD5ED835),
                                            (Name: 'mp;'; Code: $00002213),
                                            (Name: 'mscr;'; Code: $DCC2D835),
                                            (Name: 'mstpos;'; Code: $0000223E),
                                            (Name: 'mu;'; Code: $000003BC),
                                            (Name: 'multimap;'; Code: $000022B8),
                                            (Name: 'mumap;'; Code: $000022B8),
                                            (Name: 'nGg;'; Code: $033822D9),       
                                            (Name: 'nGt;'; Code: $20D2226B),
                                            (Name: 'nGtv;'; Code: $0338226B),      
                                            (Name: 'nLeftarrow;'; Code: $000021CD),
                                            (Name: 'nLeftrightarrow;'; Code: $000021CE),
                                            (Name: 'nLl;'; Code: $033822D8),             
                                            (Name: 'nLt;'; Code: $20D2226A),
                                            (Name: 'nLtv;'; Code: $0338226A),
                                            (Name: 'nRightarrow;'; Code: $000021CF),                                            
                                            (Name: 'nVDash;'; Code: $000022AF),
                                            (Name: 'nVdash;'; Code: $000022AE),
                                            (Name: 'nabla;'; Code: $00002207),
                                            (Name: 'nacute;'; Code: $00000144),
                                            (Name: 'nang;'; Code: $20D22220),
                                            (Name: 'nap;'; Code: $00002249),
                                            (Name: 'napE;'; Code: $03382A70),
                                            (Name: 'napid;'; Code: $0338224B),
                                            (Name: 'napos;'; Code: $00000149),
                                            (Name: 'napprox;'; Code: $00002249),
                                            (Name: 'natur;'; Code: $0000266E),
                                            (Name: 'natural;'; Code: $0000266E),
                                            (Name: 'naturals;'; Code: $00002115),
                                            (Name: 'nbsp'; Code: $000000A0),
                                            (Name: 'nbump;'; Code: $0338224E),
                                            (Name: 'nbumpe;'; Code: $0338224F),
                                            (Name: 'ncap;'; Code: $00002A43),
                                            (Name: 'ncaron;'; Code: $00000148),
                                            (Name: 'ncedil;'; Code: $00000146),
                                            (Name: 'ncong;'; Code: $00002247),
                                            (Name: 'ncongdot;'; Code: $03382A6D),
                                            (Name: 'ncup;'; Code: $00002A42),
                                            (Name: 'ncy;'; Code: $0000043D),
                                            (Name: 'ndash;'; Code: $00002013),
                                            (Name: 'ne;'; Code: $00002260),        
                                            (Name: 'neArr;'; Code: $000021D7),
                                            (Name: 'nearhk;'; Code: $00002924),
                                            (Name: 'nearr;'; Code: $00002197),
                                            (Name: 'nearrow;'; Code: $00002197),
                                            (Name: 'nedot;'; Code: $03382250),
                                            (Name: 'nequiv;'; Code: $00002262),
                                            (Name: 'nesear;'; Code: $00002928),
                                            (Name: 'nesim;'; Code: $03382242),
                                            (Name: 'nexist;'; Code: $00002204),
                                            (Name: 'nexists;'; Code: $00002204),
                                            (Name: 'nfr;'; Code: $DD2BD835),
                                            (Name: 'ngE;'; Code: $03382267),
                                            (Name: 'nge;'; Code: $00002271),
                                            (Name: 'ngeq;'; Code: $00002271),
                                            (Name: 'ngeqq;'; Code: $03382267),
                                            (Name: 'ngeqslant;'; Code: $03382A7E),
                                            (Name: 'nges;'; Code: $03382A7E),
                                            (Name: 'ngsim;'; Code: $00002275),
                                            (Name: 'ngt;'; Code: $0000226F),
                                            (Name: 'ngtr;'; Code: $0000226F),
                                            (Name: 'nhArr;'; Code: $000021CE),
                                            (Name: 'nharr;'; Code: $000021AE),
                                            (Name: 'nhpar;'; Code: $00002AF2),
                                            (Name: 'ni;'; Code: $0000220B),
                                            (Name: 'nis;'; Code: $000022FC),
                                            (Name: 'nisd;'; Code: $000022FA),
                                            (Name: 'niv;'; Code: $0000220B),
                                            (Name: 'njcy;'; Code: $0000045A),
                                            (Name: 'nlArr;'; Code: $000021CD),      
                                            (Name: 'nlE;'; Code: $03382266),
                                            (Name: 'nlarr;'; Code: $0000219A),
                                            (Name: 'nldr;'; Code: $00002025),
                                            (Name: 'nle;'; Code: $00002270),
                                            (Name: 'nleftarrow;'; Code: $0000219A),
                                            (Name: 'nleftrightarrow;'; Code: $000021AE),
                                            (Name: 'nleq;'; Code: $00002270),
                                            (Name: 'nleqq;'; Code: $03382266),
                                            (Name: 'nleqslant;'; Code: $03382A7D),
                                            (Name: 'nles;'; Code: $03382A7D),
                                            (Name: 'nless;'; Code: $0000226E),
                                            (Name: 'nlsim;'; Code: $00002274),
                                            (Name: 'nlt;'; Code: $0000226E),
                                            (Name: 'nltri;'; Code: $000022EA),
                                            (Name: 'nltrie;'; Code: $000022EC),
                                            (Name: 'nmid;'; Code: $00002224),
                                            (Name: 'nopf;'; Code: $DD5FD835),
                                            (Name: 'not'; Code: $000000AC),
                                            (Name: 'notin;'; Code: $00002209),    
                                            (Name: 'notinE;'; Code: $033822F9),
                                            (Name: 'notindot;'; Code: $033822F5),
                                            (Name: 'notinva;'; Code: $00002209),
                                            (Name: 'notinvb;'; Code: $000022F7),
                                            (Name: 'notinvc;'; Code: $000022F6),
                                            (Name: 'notni;'; Code: $0000220C),
                                            (Name: 'notniva;'; Code: $0000220C),
                                            (Name: 'notnivb;'; Code: $000022FE),
                                            (Name: 'notnivc;'; Code: $000022FD),
                                            (Name: 'npar;'; Code: $00002226),
                                            (Name: 'nparallel;'; Code: $00002226),
                                            (Name: 'nparsl;'; Code: $20E52AFD),
                                            (Name: 'npart;'; Code: $03382202),
                                            (Name: 'npolint;'; Code: $00002A14),
                                            (Name: 'npr;'; Code: $00002280),
                                            (Name: 'nprcue;'; Code: $000022E0),
                                            (Name: 'npre;'; Code: $03382AAF),
                                            (Name: 'nprec;'; Code: $00002280),
                                            (Name: 'npreceq;'; Code: $03382AAF),
                                            (Name: 'nrArr;'; Code: $000021CF),
                                            (Name: 'nrarr;'; Code: $0000219B),
                                            (Name: 'nrarrc;'; Code: $03382933),
                                            (Name: 'nrarrw;'; Code: $0338219D),
                                            (Name: 'nrightarrow;'; Code: $0000219B),
                                            (Name: 'nrtri;'; Code: $000022EB),
                                            (Name: 'nrtrie;'; Code: $000022ED),
                                            (Name: 'nsc;'; Code: $00002281),
                                            (Name: 'nsccue;'; Code: $000022E1),
                                            (Name: 'nsce;'; Code: $03382AB0),
                                            (Name: 'nscr;'; Code: $DCC3D835),
                                            (Name: 'nshortmid;'; Code: $00002224),
                                            (Name: 'nshortparallel;'; Code: $00002226),
                                            (Name: 'nsim;'; Code: $00002241),
                                            (Name: 'nsime;'; Code: $00002244),
                                            (Name: 'nsimeq;'; Code: $00002244),
                                            (Name: 'nsmid;'; Code: $00002224),
                                            (Name: 'nspar;'; Code: $00002226),
                                            (Name: 'nsqsube;'; Code: $000022E2),
                                            (Name: 'nsqsupe;'; Code: $000022E3),
                                            (Name: 'nsub;'; Code: $00002284),
                                            (Name: 'nsubE;'; Code: $03382AC5),
                                            (Name: 'nsube;'; Code: $00002288),
                                            (Name: 'nsubset;'; Code: $20D22282),
                                            (Name: 'nsubseteq;'; Code: $00002288),
                                            (Name: 'nsubseteqq;'; Code: $03382AC5),
                                            (Name: 'nsucc;'; Code: $00002281),
                                            (Name: 'nsucceq;'; Code: $03382AB0),
                                            (Name: 'nsup;'; Code: $00002285),
                                            (Name: 'nsupE;'; Code: $03382AC6),
                                            (Name: 'nsupe;'; Code: $00002289),
                                            (Name: 'nsupset;'; Code: $20D22283),
                                            (Name: 'nsupseteq;'; Code: $00002289),
                                            (Name: 'nsupseteqq;'; Code: $03382AC6),
                                            (Name: 'ntgl;'; Code: $00002279),
                                            (Name: 'ntilde'; Code: $000000F1),
                                            (Name: 'ntlg;'; Code: $00002278),
                                            (Name: 'ntriangleleft;'; Code: $000022EA),
                                            (Name: 'ntrianglelefteq;'; Code: $000022EC),
                                            (Name: 'ntriangleright;'; Code: $000022EB),
                                            (Name: 'ntrianglerighteq;'; Code: $000022ED),
                                            (Name: 'nu;'; Code: $000003BD),
                                            (Name: 'num;'; Code: $00000023),
                                            (Name: 'numero;'; Code: $00002116),
                                            (Name: 'numsp;'; Code: $00002007),
                                            (Name: 'nvDash;'; Code: $000022AD),
                                            (Name: 'nvHarr;'; Code: $00002904),
                                            (Name: 'nvap;'; Code: $20D2224D),
                                            (Name: 'nvdash;'; Code: $000022AC),
                                            (Name: 'nvge;'; Code: $20D22265),
                                            (Name: 'nvgt;'; Code: $20D2003E),
                                            (Name: 'nvinfin;'; Code: $000029DE),
                                            (Name: 'nvlArr;'; Code: $00002902),
                                            (Name: 'nvle;'; Code: $20D22264),
                                            (Name: 'nvlt;'; Code: $20D2003C),
                                            (Name: 'nvltrie;'; Code: $20D222B4),
                                            (Name: 'nvrArr;'; Code: $00002903),
                                            (Name: 'nvrtrie;'; Code: $20D222B5),
                                            (Name: 'nvsim;'; Code: $20D2223C),
                                            (Name: 'nwArr;'; Code: $000021D6),
                                            (Name: 'nwarhk;'; Code: $00002923),
                                            (Name: 'nwarr;'; Code: $00002196),
                                            (Name: 'nwarrow;'; Code: $00002196),
                                            (Name: 'nwnear;'; Code: $00002927),
                                            (Name: 'oS;'; Code: $000024C8),
                                            (Name: 'oacute'; Code: $000000F3),
                                            (Name: 'oast;'; Code: $0000229B),
                                            (Name: 'ocir;'; Code: $0000229A),
                                            (Name: 'ocirc'; Code: $000000F4),
                                            (Name: 'ocy;'; Code: $0000043E),
                                            (Name: 'odash;'; Code: $0000229D),
                                            (Name: 'odblac;'; Code: $00000151),
                                            (Name: 'odiv;'; Code: $00002A38),
                                            (Name: 'odot;'; Code: $00002299),
                                            (Name: 'odsold;'; Code: $000029BC),
                                            (Name: 'oelig;'; Code: $00000153),
                                            (Name: 'ofcir;'; Code: $000029BF),
                                            (Name: 'ofr;'; Code: $DD2CD835),
                                            (Name: 'ogon;'; Code: $000002DB),
                                            (Name: 'ograve'; Code: $000000F2),
                                            (Name: 'ogt;'; Code: $000029C1),
                                            (Name: 'ohbar;'; Code: $000029B5),
                                            (Name: 'ohm;'; Code: $000003A9),
                                            (Name: 'oint;'; Code: $0000222E),
                                            (Name: 'olarr;'; Code: $000021BA),
                                            (Name: 'olcir;'; Code: $000029BE),
                                            (Name: 'olcross;'; Code: $000029BB),
                                            (Name: 'oline;'; Code: $0000203E),
                                            (Name: 'olt;'; Code: $000029C0),
                                            (Name: 'omacr;'; Code: $0000014D),
                                            (Name: 'omega;'; Code: $000003C9),
                                            (Name: 'omicron;'; Code: $000003BF),
                                            (Name: 'omid;'; Code: $000029B6),
                                            (Name: 'ominus;'; Code: $00002296),
                                            (Name: 'oopf;'; Code: $DD60D835),
                                            (Name: 'opar;'; Code: $000029B7),
                                            (Name: 'operp;'; Code: $000029B9),
                                            (Name: 'oplus;'; Code: $00002295),
                                            (Name: 'or;'; Code: $00002228),
                                            (Name: 'orarr;'; Code: $000021BB),
                                            (Name: 'ord;'; Code: $00002A5D),
                                            (Name: 'order;'; Code: $00002134),
                                            (Name: 'orderof;'; Code: $00002134),
                                            (Name: 'ordf'; Code: $000000AA),
                                            (Name: 'ordm'; Code: $000000BA),
                                            (Name: 'origof;'; Code: $000022B6),
                                            (Name: 'oror;'; Code: $00002A56),
                                            (Name: 'orslope;'; Code: $00002A57),
                                            (Name: 'orv;'; Code: $00002A5B),
                                            (Name: 'oscr;'; Code: $00002134),
                                            (Name: 'oslash'; Code: $000000F8),
                                            (Name: 'osol;'; Code: $00002298),
                                            (Name: 'otilde'; Code: $000000F5),
                                            (Name: 'otimes;'; Code: $00002297),
                                            (Name: 'otimesas;'; Code: $00002A36),
                                            (Name: 'ouml'; Code: $000000F6),
                                            (Name: 'ovbar;'; Code: $0000233D),
                                            (Name: 'par;'; Code: $00002225),
                                            (Name: 'para'; Code: $000000B6),
                                            (Name: 'parallel;'; Code: $00002225),
                                            (Name: 'parsim;'; Code: $00002AF3),
                                            (Name: 'parsl;'; Code: $00002AFD),
                                            (Name: 'part;'; Code: $00002202),
                                            (Name: 'pcy;'; Code: $0000043F),
                                            (Name: 'percnt;'; Code: $00000025),
                                            (Name: 'period;'; Code: $0000002E),
                                            (Name: 'permil;'; Code: $00002030),
                                            (Name: 'perp;'; Code: $000022A5),
                                            (Name: 'pertenk;'; Code: $00002031),
                                            (Name: 'pfr;'; Code: $DD2DD835),
                                            (Name: 'phi;'; Code: $000003C6),
                                            (Name: 'phiv;'; Code: $000003D5),
                                            (Name: 'phmmat;'; Code: $00002133),
                                            (Name: 'phone;'; Code: $0000260E),
                                            (Name: 'pi;'; Code: $000003C0),
                                            (Name: 'pitchfork;'; Code: $000022D4),
                                            (Name: 'piv;'; Code: $000003D6),
                                            (Name: 'planck;'; Code: $0000210F),
                                            (Name: 'planckh;'; Code: $0000210E),
                                            (Name: 'plankv;'; Code: $0000210F),
                                            (Name: 'plus;'; Code: $0000002B),
                                            (Name: 'plusacir;'; Code: $00002A23),
                                            (Name: 'plusb;'; Code: $0000229E),
                                            (Name: 'pluscir;'; Code: $00002A22),
                                            (Name: 'plusdo;'; Code: $00002214),
                                            (Name: 'plusdu;'; Code: $00002A25),
                                            (Name: 'pluse;'; Code: $00002A72),
                                            (Name: 'plusmn'; Code: $000000B1),
                                            (Name: 'plussim;'; Code: $00002A26),
                                            (Name: 'plustwo;'; Code: $00002A27),
                                            (Name: 'pm;'; Code: $000000B1),
                                            (Name: 'pointint;'; Code: $00002A15),
                                            (Name: 'popf;'; Code: $DD61D835),
                                            (Name: 'pound'; Code: $000000A3),
                                            (Name: 'pr;'; Code: $0000227A),
                                            (Name: 'prE;'; Code: $00002AB3),
                                            (Name: 'prap;'; Code: $00002AB7),
                                            (Name: 'prcue;'; Code: $0000227C),
                                            (Name: 'pre;'; Code: $00002AAF),
                                            (Name: 'prec;'; Code: $0000227A),
                                            (Name: 'precapprox;'; Code: $00002AB7),
                                            (Name: 'preccurlyeq;'; Code: $0000227C),
                                            (Name: 'preceq;'; Code: $00002AAF),
                                            (Name: 'precnapprox;'; Code: $00002AB9),
                                            (Name: 'precneqq;'; Code: $00002AB5),
                                            (Name: 'precnsim;'; Code: $000022E8),
                                            (Name: 'precsim;'; Code: $0000227E),
                                            (Name: 'prime;'; Code: $00002032),
                                            (Name: 'primes;'; Code: $00002119),
                                            (Name: 'prnE;'; Code: $00002AB5),
                                            (Name: 'prnap;'; Code: $00002AB9),
                                            (Name: 'prnsim;'; Code: $000022E8),
                                            (Name: 'prod;'; Code: $0000220F),
                                            (Name: 'profalar;'; Code: $0000232E),
                                            (Name: 'profline;'; Code: $00002312),
                                            (Name: 'profsurf;'; Code: $00002313),
                                            (Name: 'prop;'; Code: $0000221D),
                                            (Name: 'propto;'; Code: $0000221D),
                                            (Name: 'prsim;'; Code: $0000227E),
                                            (Name: 'prurel;'; Code: $000022B0),
                                            (Name: 'pscr;'; Code: $DCC5D835),
                                            (Name: 'psi;'; Code: $000003C8),
                                            (Name: 'puncsp;'; Code: $00002008),
                                            (Name: 'qfr;'; Code: $DD2ED835),
                                            (Name: 'qint;'; Code: $00002A0C),
                                            (Name: 'qopf;'; Code: $DD62D835),
                                            (Name: 'qprime;'; Code: $00002057),
                                            (Name: 'qscr;'; Code: $DCC6D835),
                                            (Name: 'quaternions;'; Code: $0000210D),
                                            (Name: 'quatint;'; Code: $00002A16),
                                            (Name: 'quest;'; Code: $0000003F),
                                            (Name: 'questeq;'; Code: $0000225F),
                                            (Name: 'quot;'; Code: $00000022),
                                            (Name: 'rAarr;'; Code: $000021DB),
                                            (Name: 'rArr;'; Code: $000021D2),
                                            (Name: 'rAtail;'; Code: $0000291C),
                                            (Name: 'rBarr;'; Code: $0000290F),
                                            (Name: 'rHar;'; Code: $00002964),
                                            (Name: 'race;'; Code: $0331223D),
                                            (Name: 'racute;'; Code: $00000155),
                                            (Name: 'radic;'; Code: $0000221A),
                                            (Name: 'raemptyv;'; Code: $000029B3),
                                            (Name: 'rang;'; Code: $000027E9),
                                            (Name: 'rangd;'; Code: $00002992),
                                            (Name: 'range;'; Code: $000029A5),
                                            (Name: 'rangle;'; Code: $000027E9),
                                            (Name: 'raquo'; Code: $000000BB),
                                            (Name: 'rarr;'; Code: $00002192),
                                            (Name: 'rarrap;'; Code: $00002975),
                                            (Name: 'rarrb;'; Code: $000021E5),
                                            (Name: 'rarrbfs;'; Code: $00002920),
                                            (Name: 'rarrc;'; Code: $00002933),
                                            (Name: 'rarrfs;'; Code: $0000291E),
                                            (Name: 'rarrhk;'; Code: $000021AA),
                                            (Name: 'rarrlp;'; Code: $000021AC),
                                            (Name: 'rarrpl;'; Code: $00002945),
                                            (Name: 'rarrsim;'; Code: $00002974),
                                            (Name: 'rarrtl;'; Code: $000021A3),
                                            (Name: 'rarrw;'; Code: $0000219D),
                                            (Name: 'ratail;'; Code: $0000291A),
                                            (Name: 'ratio;'; Code: $00002236),
                                            (Name: 'rationals;'; Code: $0000211A),
                                            (Name: 'rbarr;'; Code: $0000290D),
                                            (Name: 'rbbrk;'; Code: $00002773),
                                            (Name: 'rbrace;'; Code: $0000007D),
                                            (Name: 'rbrack;'; Code: $0000005D),
                                            (Name: 'rbrke;'; Code: $0000298C),
                                            (Name: 'rbrksld;'; Code: $0000298E),
                                            (Name: 'rbrkslu;'; Code: $00002990),
                                            (Name: 'rcaron;'; Code: $00000159),
                                            (Name: 'rcedil;'; Code: $00000157),
                                            (Name: 'rceil;'; Code: $00002309),
                                            (Name: 'rcub;'; Code: $0000007D),
                                            (Name: 'rcy;'; Code: $00000440),
                                            (Name: 'rdca;'; Code: $00002937),
                                            (Name: 'rdldhar;'; Code: $00002969),
                                            (Name: 'rdquo;'; Code: $0000201D),
                                            (Name: 'rdquor;'; Code: $0000201D),
                                            (Name: 'rdsh;'; Code: $000021B3),
                                            (Name: 'real;'; Code: $0000211C),
                                            (Name: 'realine;'; Code: $0000211B),
                                            (Name: 'realpart;'; Code: $0000211C),
                                            (Name: 'reals;'; Code: $0000211D),
                                            (Name: 'rect;'; Code: $000025AD),
                                            (Name: 'reg'; Code: $000000AE),
                                            (Name: 'rfisht;'; Code: $0000297D),
                                            (Name: 'rfloor;'; Code: $0000230B),
                                            (Name: 'rfr;'; Code: $DD2FD835),
                                            (Name: 'rhard;'; Code: $000021C1),
                                            (Name: 'rharu;'; Code: $000021C0),
                                            (Name: 'rharul;'; Code: $0000296C),
                                            (Name: 'rho;'; Code: $000003C1),
                                            (Name: 'rhov;'; Code: $000003F1),
                                            (Name: 'rightarrow;'; Code: $00002192),
                                            (Name: 'rightarrowtail;'; Code: $000021A3),
                                            (Name: 'rightharpoondown;'; Code: $000021C1),
                                            (Name: 'rightharpoonup;'; Code: $000021C0),
                                            (Name: 'rightleftarrows;'; Code: $000021C4),
                                            (Name: 'rightleftharpoons;'; Code: $000021CC),
                                            (Name: 'rightrightarrows;'; Code: $000021C9),
                                            (Name: 'rightsquigarrow;'; Code: $0000219D),
                                            (Name: 'rightthreetimes;'; Code: $000022CC),
                                            (Name: 'ring;'; Code: $000002DA),
                                            (Name: 'risingdotseq;'; Code: $00002253),
                                            (Name: 'rlarr;'; Code: $000021C4),
                                            (Name: 'rlhar;'; Code: $000021CC),
                                            (Name: 'rlm;'; Code: $0000200F),
                                            (Name: 'rmoust;'; Code: $000023B1),
                                            (Name: 'rmoustache;'; Code: $000023B1),
                                            (Name: 'rnmid;'; Code: $00002AEE),
                                            (Name: 'roang;'; Code: $000027ED),
                                            (Name: 'roarr;'; Code: $000021FE),
                                            (Name: 'robrk;'; Code: $000027E7),
                                            (Name: 'ropar;'; Code: $00002986),
                                            (Name: 'ropf;'; Code: $DD63D835),
                                            (Name: 'roplus;'; Code: $00002A2E),
                                            (Name: 'rotimes;'; Code: $00002A35),
                                            (Name: 'rpar;'; Code: $00000029),
                                            (Name: 'rpargt;'; Code: $00002994),
                                            (Name: 'rppolint;'; Code: $00002A12),
                                            (Name: 'rrarr;'; Code: $000021C9),
                                            (Name: 'rsaquo;'; Code: $0000203A),
                                            (Name: 'rscr;'; Code: $DCC7D835),
                                            (Name: 'rsh;'; Code: $000021B1),
                                            (Name: 'rsqb;'; Code: $0000005D),
                                            (Name: 'rsquo;'; Code: $00002019),
                                            (Name: 'rsquor;'; Code: $00002019),
                                            (Name: 'rthree;'; Code: $000022CC),
                                            (Name: 'rtimes;'; Code: $000022CA),
                                            (Name: 'rtri;'; Code: $000025B9),
                                            (Name: 'rtrie;'; Code: $000022B5),
                                            (Name: 'rtrif;'; Code: $000025B8),
                                            (Name: 'rtriltri;'; Code: $000029CE),
                                            (Name: 'ruluhar;'; Code: $00002968),
                                            (Name: 'rx;'; Code: $0000211E),
                                            (Name: 'sacute;'; Code: $0000015B),
                                            (Name: 'sbquo;'; Code: $0000201A),
                                            (Name: 'sc;'; Code: $0000227B),
                                            (Name: 'scE;'; Code: $00002AB4),
                                            (Name: 'scap;'; Code: $00002AB8),
                                            (Name: 'scaron;'; Code: $00000161),
                                            (Name: 'sccue;'; Code: $0000227D),
                                            (Name: 'sce;'; Code: $00002AB0),
                                            (Name: 'scedil;'; Code: $0000015F),
                                            (Name: 'scirc;'; Code: $0000015D),
                                            (Name: 'scnE;'; Code: $00002AB6),
                                            (Name: 'scnap;'; Code: $00002ABA),
                                            (Name: 'scnsim;'; Code: $000022E9),
                                            (Name: 'scpolint;'; Code: $00002A13),
                                            (Name: 'scsim;'; Code: $0000227F),
                                            (Name: 'scy;'; Code: $00000441),
                                            (Name: 'sdot;'; Code: $000022C5),
                                            (Name: 'sdotb;'; Code: $000022A1),
                                            (Name: 'sdote;'; Code: $00002A66),
                                            (Name: 'seArr;'; Code: $000021D8),
                                            (Name: 'searhk;'; Code: $00002925),
                                            (Name: 'searr;'; Code: $00002198),
                                            (Name: 'searrow;'; Code: $00002198),
                                            (Name: 'sect'; Code: $000000A7),
                                            (Name: 'semi;'; Code: $0000003B),
                                            (Name: 'seswar;'; Code: $00002929),
                                            (Name: 'setminus;'; Code: $00002216),
                                            (Name: 'setmn;'; Code: $00002216),
                                            (Name: 'sext;'; Code: $00002736),
                                            (Name: 'sfr;'; Code: $DD30D835),
                                            (Name: 'sfrown;'; Code: $00002322),
                                            (Name: 'sharp;'; Code: $0000266F),
                                            (Name: 'shchcy;'; Code: $00000449),
                                            (Name: 'shcy;'; Code: $00000448),
                                            (Name: 'shortmid;'; Code: $00002223),
                                            (Name: 'shortparallel;'; Code: $00002225),
                                            (Name: 'shy'; Code: $000000AD),
                                            (Name: 'sigma;'; Code: $000003C3),
                                            (Name: 'sigmaf;'; Code: $000003C2),
                                            (Name: 'sigmav;'; Code: $000003C2),
                                            (Name: 'sim;'; Code: $0000223C),
                                            (Name: 'simdot;'; Code: $00002A6A),
                                            (Name: 'sime;'; Code: $00002243),
                                            (Name: 'simeq;'; Code: $00002243),
                                            (Name: 'simg;'; Code: $00002A9E),
                                            (Name: 'simgE;'; Code: $00002AA0),
                                            (Name: 'siml;'; Code: $00002A9D),
                                            (Name: 'simlE;'; Code: $00002A9F),
                                            (Name: 'simne;'; Code: $00002246),
                                            (Name: 'simplus;'; Code: $00002A24),
                                            (Name: 'simrarr;'; Code: $00002972),
                                            (Name: 'slarr;'; Code: $00002190),
                                            (Name: 'smallsetminus;'; Code: $00002216),
                                            (Name: 'smashp;'; Code: $00002A33),
                                            (Name: 'smeparsl;'; Code: $000029E4),
                                            (Name: 'smid;'; Code: $00002223),
                                            (Name: 'smile;'; Code: $00002323),
                                            (Name: 'smt;'; Code: $00002AAA),
                                            (Name: 'smte;'; Code: $00002AAC),
                                            (Name: 'smtes;'; Code: $FE002AAC),
                                            (Name: 'softcy;'; Code: $0000044C),
                                            (Name: 'sol;'; Code: $0000002F),
                                            (Name: 'solb;'; Code: $000029C4),
                                            (Name: 'solbar;'; Code: $0000233F),
                                            (Name: 'sopf;'; Code: $DD64D835),
                                            (Name: 'spades;'; Code: $00002660),
                                            (Name: 'spadesuit;'; Code: $00002660),
                                            (Name: 'spar;'; Code: $00002225),
                                            (Name: 'sqcap;'; Code: $00002293),
                                            (Name: 'sqcaps;'; Code: $FE002293),
                                            (Name: 'sqcup;'; Code: $00002294),
                                            (Name: 'sqcups;'; Code: $FE002294),
                                            (Name: 'sqsub;'; Code: $0000228F),
                                            (Name: 'sqsube;'; Code: $00002291),
                                            (Name: 'sqsubset;'; Code: $0000228F),
                                            (Name: 'sqsubseteq;'; Code: $00002291),
                                            (Name: 'sqsup;'; Code: $00002290),
                                            (Name: 'sqsupe;'; Code: $00002292),
                                            (Name: 'sqsupset;'; Code: $00002290),
                                            (Name: 'sqsupseteq;'; Code: $00002292),
                                            (Name: 'squ;'; Code: $000025A1),
                                            (Name: 'square;'; Code: $000025A1),
                                            (Name: 'squarf;'; Code: $000025AA),
                                            (Name: 'squf;'; Code: $000025AA),
                                            (Name: 'srarr;'; Code: $00002192),
                                            (Name: 'sscr;'; Code: $DCC8D835),
                                            (Name: 'ssetmn;'; Code: $00002216),
                                            (Name: 'ssmile;'; Code: $00002323),
                                            (Name: 'sstarf;'; Code: $000022C6),
                                            (Name: 'star;'; Code: $00002606),
                                            (Name: 'starf;'; Code: $00002605),
                                            (Name: 'straightepsilon;'; Code: $000003F5),
                                            (Name: 'straightphi;'; Code: $000003D5),
                                            (Name: 'strns;'; Code: $000000AF),
                                            (Name: 'sub;'; Code: $00002282),
                                            (Name: 'subE;'; Code: $00002AC5),
                                            (Name: 'subdot;'; Code: $00002ABD),
                                            (Name: 'sube;'; Code: $00002286),
                                            (Name: 'subedot;'; Code: $00002AC3),
                                            (Name: 'submult;'; Code: $00002AC1),
                                            (Name: 'subnE;'; Code: $00002ACB),
                                            (Name: 'subne;'; Code: $0000228A),
                                            (Name: 'subplus;'; Code: $00002ABF),
                                            (Name: 'subrarr;'; Code: $00002979),
                                            (Name: 'subset;'; Code: $00002282),
                                            (Name: 'subseteq;'; Code: $00002286),
                                            (Name: 'subseteqq;'; Code: $00002AC5),
                                            (Name: 'subsetneq;'; Code: $0000228A),
                                            (Name: 'subsetneqq;'; Code: $00002ACB),
                                            (Name: 'subsim;'; Code: $00002AC7),
                                            (Name: 'subsub;'; Code: $00002AD5),
                                            (Name: 'subsup;'; Code: $00002AD3),
                                            (Name: 'succ;'; Code: $0000227B),
                                            (Name: 'succapprox;'; Code: $00002AB8),
                                            (Name: 'succcurlyeq;'; Code: $0000227D),
                                            (Name: 'succeq;'; Code: $00002AB0),
                                            (Name: 'succnapprox;'; Code: $00002ABA),
                                            (Name: 'succneqq;'; Code: $00002AB6),
                                            (Name: 'succnsim;'; Code: $000022E9),
                                            (Name: 'succsim;'; Code: $0000227F),
                                            (Name: 'sum;'; Code: $00002211),
                                            (Name: 'sung;'; Code: $0000266A),
                                            (Name: 'sup1'; Code: $000000B9),
                                            (Name: 'sup2'; Code: $000000B2),
                                            (Name: 'sup3'; Code: $000000B3),
                                            (Name: 'sup;'; Code: $00002283),
                                            (Name: 'supE;'; Code: $00002AC6),
                                            (Name: 'supdot;'; Code: $00002ABE),
                                            (Name: 'supdsub;'; Code: $00002AD8),
                                            (Name: 'supe;'; Code: $00002287),
                                            (Name: 'supedot;'; Code: $00002AC4),
                                            (Name: 'suphsol;'; Code: $000027C9),
                                            (Name: 'suphsub;'; Code: $00002AD7),
                                            (Name: 'suplarr;'; Code: $0000297B),
                                            (Name: 'supmult;'; Code: $00002AC2),
                                            (Name: 'supnE;'; Code: $00002ACC),
                                            (Name: 'supne;'; Code: $0000228B),
                                            (Name: 'supplus;'; Code: $00002AC0),
                                            (Name: 'supset;'; Code: $00002283),
                                            (Name: 'supseteq;'; Code: $00002287),
                                            (Name: 'supseteqq;'; Code: $00002AC6),
                                            (Name: 'supsetneq;'; Code: $0000228B),
                                            (Name: 'supsetneqq;'; Code: $00002ACC),
                                            (Name: 'supsim;'; Code: $00002AC8),
                                            (Name: 'supsub;'; Code: $00002AD4),
                                            (Name: 'supsup;'; Code: $00002AD6),
                                            (Name: 'swArr;'; Code: $000021D9),
                                            (Name: 'swarhk;'; Code: $00002926),
                                            (Name: 'swarr;'; Code: $00002199),
                                            (Name: 'swarrow;'; Code: $00002199),
                                            (Name: 'swnwar;'; Code: $0000292A),
                                            (Name: 'szlig'; Code: $000000DF),
                                            (Name: 'target;'; Code: $00002316),
                                            (Name: 'tau;'; Code: $000003C4),
                                            (Name: 'tbrk;'; Code: $000023B4),
                                            (Name: 'tcaron;'; Code: $00000165),
                                            (Name: 'tcedil;'; Code: $00000163),
                                            (Name: 'tcy;'; Code: $00000442),
                                            (Name: 'tdot;'; Code: $000020DB),
                                            (Name: 'telrec;'; Code: $00002315),
                                            (Name: 'tfr;'; Code: $DD31D835),
                                            (Name: 'there4;'; Code: $00002234),
                                            (Name: 'therefore;'; Code: $00002234),
                                            (Name: 'theta;'; Code: $000003B8),
                                            (Name: 'thetasym;'; Code: $000003D1),
                                            (Name: 'thetav;'; Code: $000003D1),
                                            (Name: 'thickapprox;'; Code: $00002248),
                                            (Name: 'thicksim;'; Code: $0000223C),
                                            (Name: 'thinsp;'; Code: $00002009),
                                            (Name: 'thkap;'; Code: $00002248),
                                            (Name: 'thksim;'; Code: $0000223C),
                                            (Name: 'thorn'; Code: $000000FE),
                                            (Name: 'tilde;'; Code: $000002DC),
                                            (Name: 'times'; Code: $000000D7),
                                            (Name: 'timesb;'; Code: $000022A0),
                                            (Name: 'timesbar;'; Code: $00002A31),
                                            (Name: 'timesd;'; Code: $00002A30),
                                            (Name: 'tint;'; Code: $0000222D),
                                            (Name: 'toea;'; Code: $00002928),
                                            (Name: 'top;'; Code: $000022A4),
                                            (Name: 'topbot;'; Code: $00002336),
                                            (Name: 'topcir;'; Code: $00002AF1),
                                            (Name: 'topf;'; Code: $DD65D835),
                                            (Name: 'topfork;'; Code: $00002ADA),
                                            (Name: 'tosa;'; Code: $00002929),
                                            (Name: 'tprime;'; Code: $00002034),
                                            (Name: 'trade;'; Code: $00002122),
                                            (Name: 'triangle;'; Code: $000025B5),
                                            (Name: 'triangledown;'; Code: $000025BF),
                                            (Name: 'triangleleft;'; Code: $000025C3),
                                            (Name: 'trianglelefteq;'; Code: $000022B4),
                                            (Name: 'triangleq;'; Code: $0000225C),
                                            (Name: 'triangleright;'; Code: $000025B9),
                                            (Name: 'trianglerighteq;'; Code: $000022B5),
                                            (Name: 'tridot;'; Code: $000025EC),
                                            (Name: 'trie;'; Code: $0000225C),
                                            (Name: 'triminus;'; Code: $00002A3A),
                                            (Name: 'triplus;'; Code: $00002A39),
                                            (Name: 'trisb;'; Code: $000029CD),
                                            (Name: 'tritime;'; Code: $00002A3B),
                                            (Name: 'trpezium;'; Code: $000023E2),
                                            (Name: 'tscr;'; Code: $DCC9D835),
                                            (Name: 'tscy;'; Code: $00000446),
                                            (Name: 'tshcy;'; Code: $0000045B),
                                            (Name: 'tstrok;'; Code: $00000167),
                                            (Name: 'twixt;'; Code: $0000226C),
                                            (Name: 'twoheadleftarrow;'; Code: $0000219E),
                                            (Name: 'twoheadrightarrow;'; Code: $000021A0),
                                            (Name: 'uArr;'; Code: $000021D1),
                                            (Name: 'uHar;'; Code: $00002963),
                                            (Name: 'uacute'; Code: $000000FA),
                                            (Name: 'uarr;'; Code: $00002191),
                                            (Name: 'ubrcy;'; Code: $0000045E),
                                            (Name: 'ubreve;'; Code: $0000016D),
                                            (Name: 'ucirc'; Code: $000000FB),
                                            (Name: 'ucy;'; Code: $00000443),
                                            (Name: 'udarr;'; Code: $000021C5),
                                            (Name: 'udblac;'; Code: $00000171),
                                            (Name: 'udhar;'; Code: $0000296E),
                                            (Name: 'ufisht;'; Code: $0000297E),
                                            (Name: 'ufr;'; Code: $DD32D835),
                                            (Name: 'ugrave'; Code: $000000F9),
                                            (Name: 'uharl;'; Code: $000021BF),
                                            (Name: 'uharr;'; Code: $000021BE),
                                            (Name: 'uhblk;'; Code: $00002580),
                                            (Name: 'ulcorn;'; Code: $0000231C),
                                            (Name: 'ulcorner;'; Code: $0000231C),
                                            (Name: 'ulcrop;'; Code: $0000230F),
                                            (Name: 'ultri;'; Code: $000025F8),
                                            (Name: 'umacr;'; Code: $0000016B),
                                            (Name: 'uml'; Code: $000000A8),
                                            (Name: 'uogon;'; Code: $00000173),
                                            (Name: 'uopf;'; Code: $DD66D835),
                                            (Name: 'uparrow;'; Code: $00002191),
                                            (Name: 'updownarrow;'; Code: $00002195),
                                            (Name: 'upharpoonleft;'; Code: $000021BF),
                                            (Name: 'upharpoonright;'; Code: $000021BE),
                                            (Name: 'uplus;'; Code: $0000228E),
                                            (Name: 'upsi;'; Code: $000003C5),
                                            (Name: 'upsih;'; Code: $000003D2),
                                            (Name: 'upsilon;'; Code: $000003C5),
                                            (Name: 'upuparrows;'; Code: $000021C8),
                                            (Name: 'urcorn;'; Code: $0000231D),
                                            (Name: 'urcorner;'; Code: $0000231D),
                                            (Name: 'urcrop;'; Code: $0000230E),
                                            (Name: 'uring;'; Code: $0000016F),
                                            (Name: 'urtri;'; Code: $000025F9),
                                            (Name: 'uscr;'; Code: $DCCAD835),
                                            (Name: 'utdot;'; Code: $000022F0),
                                            (Name: 'utilde;'; Code: $00000169),
                                            (Name: 'utri;'; Code: $000025B5),
                                            (Name: 'utrif;'; Code: $000025B4),
                                            (Name: 'uuarr;'; Code: $000021C8),
                                            (Name: 'uuml'; Code: $000000FC),
                                            (Name: 'uwangle;'; Code: $000029A7),
                                            (Name: 'vArr;'; Code: $000021D5),
                                            (Name: 'vBar;'; Code: $00002AE8),
                                            (Name: 'vBarv;'; Code: $00002AE9),
                                            (Name: 'vDash;'; Code: $000022A8),
                                            (Name: 'vangrt;'; Code: $0000299C),
                                            (Name: 'varepsilon;'; Code: $000003F5),
                                            (Name: 'varkappa;'; Code: $000003F0),
                                            (Name: 'varnothing;'; Code: $00002205),
                                            (Name: 'varphi;'; Code: $000003D5),
                                            (Name: 'varpi;'; Code: $000003D6),
                                            (Name: 'varpropto;'; Code: $0000221D),
                                            (Name: 'varr;'; Code: $00002195),
                                            (Name: 'varrho;'; Code: $000003F1),
                                            (Name: 'varsigma;'; Code: $000003C2),
                                            (Name: 'varsubsetneq;'; Code: $FE00228A),
                                            (Name: 'varsubsetneqq;'; Code: $FE002ACB),
                                            (Name: 'varsupsetneq;'; Code: $FE00228B),
                                            (Name: 'varsupsetneqq;'; Code: $FE002ACC),
                                            (Name: 'vartheta;'; Code: $000003D1),
                                            (Name: 'vartriangleleft;'; Code: $000022B2),
                                            (Name: 'vartriangleright;'; Code: $000022B3),
                                            (Name: 'vcy;'; Code: $00000432),
                                            (Name: 'vdash;'; Code: $000022A2),
                                            (Name: 'vee;'; Code: $00002228),
                                            (Name: 'veebar;'; Code: $000022BB),
                                            (Name: 'veeeq;'; Code: $0000225A),
                                            (Name: 'vellip;'; Code: $000022EE),
                                            (Name: 'verbar;'; Code: $0000007C),
                                            (Name: 'vert;'; Code: $0000007C),
                                            (Name: 'vfr;'; Code: $DD33D835),
                                            (Name: 'vltri;'; Code: $000022B2),
                                            (Name: 'vnsub;'; Code: $20D22282),
                                            (Name: 'vnsup;'; Code: $20D22283),
                                            (Name: 'vopf;'; Code: $DD67D835),
                                            (Name: 'vprop;'; Code: $0000221D),
                                            (Name: 'vrtri;'; Code: $000022B3),
                                            (Name: 'vscr;'; Code: $DCCBD835),
                                            (Name: 'vsubnE;'; Code: $FE002ACB),
                                            (Name: 'vsubne;'; Code: $FE00228A),
                                            (Name: 'vsupnE;'; Code: $FE002ACC),
                                            (Name: 'vsupne;'; Code: $FE00228B),
                                            (Name: 'vzigzag;'; Code: $0000299A),
                                            (Name: 'wcirc;'; Code: $00000175),
                                            (Name: 'wedbar;'; Code: $00002A5F),
                                            (Name: 'wedge;'; Code: $00002227),
                                            (Name: 'wedgeq;'; Code: $00002259),
                                            (Name: 'weierp;'; Code: $00002118),
                                            (Name: 'wfr;'; Code: $DD34D835),
                                            (Name: 'wopf;'; Code: $DD68D835),
                                            (Name: 'wp;'; Code: $00002118),
                                            (Name: 'wr;'; Code: $00002240),
                                            (Name: 'wreath;'; Code: $00002240),
                                            (Name: 'wscr;'; Code: $DCCCD835),
                                            (Name: 'xcap;'; Code: $000022C2),
                                            (Name: 'xcirc;'; Code: $000025EF),
                                            (Name: 'xcup;'; Code: $000022C3),
                                            (Name: 'xdtri;'; Code: $000025BD),
                                            (Name: 'xfr;'; Code: $DD35D835),
                                            (Name: 'xhArr;'; Code: $000027FA),
                                            (Name: 'xharr;'; Code: $000027F7),
                                            (Name: 'xi;'; Code: $000003BE),
                                            (Name: 'xlArr;'; Code: $000027F8),
                                            (Name: 'xlarr;'; Code: $000027F5),
                                            (Name: 'xmap;'; Code: $000027FC),
                                            (Name: 'xnis;'; Code: $000022FB),
                                            (Name: 'xodot;'; Code: $00002A00),
                                            (Name: 'xopf;'; Code: $DD69D835),
                                            (Name: 'xoplus;'; Code: $00002A01),
                                            (Name: 'xotime;'; Code: $00002A02),
                                            (Name: 'xrArr;'; Code: $000027F9),
                                            (Name: 'xrarr;'; Code: $000027F6),
                                            (Name: 'xscr;'; Code: $DCCDD835),
                                            (Name: 'xsqcup;'; Code: $00002A06),
                                            (Name: 'xuplus;'; Code: $00002A04),
                                            (Name: 'xutri;'; Code: $000025B3),
                                            (Name: 'xvee;'; Code: $000022C1),
                                            (Name: 'xwedge;'; Code: $000022C0),
                                            (Name: 'yacute'; Code: $000000FD),
                                            (Name: 'yacy;'; Code: $0000044F),
                                            (Name: 'ycirc;'; Code: $00000177),
                                            (Name: 'ycy;'; Code: $0000044B),
                                            (Name: 'yen'; Code: $000000A5),
                                            (Name: 'yfr;'; Code: $DD36D835),
                                            (Name: 'yicy;'; Code: $00000457),
                                            (Name: 'yopf;'; Code: $DD6AD835),
                                            (Name: 'yscr;'; Code: $DCCED835),
                                            (Name: 'yucy;'; Code: $0000044E),
                                            (Name: 'yuml'; Code: $000000FF),
                                            (Name: 'zacute;'; Code: $0000017A),
                                            (Name: 'zcaron;'; Code: $0000017E),
                                            (Name: 'zcy;'; Code: $00000437),
                                            (Name: 'zdot;'; Code: $0000017C),
                                            (Name: 'zeetrf;'; Code: $00002128),
                                            (Name: 'zeta;'; Code: $000003B6),
                                            (Name: 'zfr;'; Code: $DD37D835),
                                            (Name: 'zhcy;'; Code: $00000436),
                                            (Name: 'zigrarr;'; Code: $000021DD),
                                            (Name: 'zopf;'; Code: $DD6BD835),
                                            (Name: 'zscr;'; Code: $DCCFD835),
                                            (Name: 'zwj;'; Code: $0000200D),
                                            (Name: 'zwnj;'; Code: $0000200C));

implementation

uses
  AnsiStrings;

function UCS4Chr(c: Cardinal): UnicodeString;
begin
  if c < $10000 then
  Result := Chr(c)
  else
  Result := Chr((c - $10000) shr 10 and $3FF or $D800) + Chr((c - $10000) and $3FF or $DC00);
end;

function RemoveEntities(s: string): string;
var
  i, j, k: Integer;
  s2: string;
  entityresult: string;
procedure FindEntity(Pattern: AnsiString; Low, High: Integer; var Result: string);
var
  n: Integer;
begin
  // Fail
  if Low > High then
  Exit;

  n := (Low+High) div 2;

  if StartsStr(Entities[n].Name, Pattern) then
  begin
    Result := Chr(Word(Entities[n].Code));
    if Entities[n].Code > 65535 then
    Result := Result + Chr(Word(Entities[n].Code shr 16));
    inc(i,Length(Entities[n].Name));
    // Die, die kein Apostroph haben, knnen eins haben
    if not AnsiStrings.EndsStr(';', Entities[n].Name) then
    begin
      Delete(Pattern, 1, Length(Entities[n].Name));
      if AnsiStrings.StartsStr(';', Pattern) then
      inc(i);
    end;
  end
  else
  if Entities[n].Name > Pattern then
  FindEntity(Pattern, Low, n-1, Result)
  else
  if Entities[n].Name < Pattern then
  FindEntity(Pattern, n+1, High, Result);
end;
begin
  j := Length(s);
  k := 0;
  i := 1;
  Result := '';
  while i <= j do
  begin
    if s[i] = '&' then
    begin
      inc(i);
      s2 := Copy(s, i, 32);
      if StartsStr('#', s2) then
      begin
        s2 := Copy(s, i + 1, PosEx(';', s, i) - i - 1);
        if TryStrToInt(s2, k) then // Untersttzt netterweise Hex-Strings
        Result := Result + UCS4Chr(k)
        else
        Result := Result + '&#' + s2 + ';';
        inc(i, Length(s2) + 3);
      end
      else
      begin
        Entityresult := '&';
        FindEntity(AnsiString(s2), Low(Entities), High(Entities), EntityResult);
        Result := Result + EntityResult;
      end;
    end
    else
    begin
      Result := Result + s[i];
      inc(i);
    end;
  end;
end;

end.
